@@ -3,8 +3,33 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
+!BOP
+! !ROUTINE: bdipole
+! !INTERFACE:
 subroutine bdipole
+! !USES:
 use modmain
+! !DESCRIPTION:
+!   Calculates the magnetic dipole field arising from the spin and orbital
+!   current. The total current density is
+!   $$ {\bf j}({\bf r}) = {\rm Im}\sum_{i{\bf k}}^{\rm occ}
+!    \varphi_{i{\bf k}}^{\dag}({\bf r})\nabla\varphi_{i{\bf k}}({\bf r})
+!    -\frac{1}{c}{\bf A}\,\rho({\bf r})
+!    +\frac{g_s}{4}\nabla\times{\bf m}({\bf r}), $$
+!   where $g_s$ is the electron spin $g$-factor. The vector potential arising
+!   from ${\bf j}({\bf r})$ is calculated by
+!   $$ {\bf A}({\bf r})=\frac{1}{c}\int d^3r'\,\frac{{\bf j}({\bf r}')}
+!    {|{\bf r}-{\bf r}'|}, $$
+!   using the Poisson equation solver {\tt zpotcoul}. Finally, the magnetic
+!   field is determined from ${\bf B}({\bf r})=\nabla\times{\bf A}({\bf r})$.
+!   This field is included as a Zeeman term in the second-variational
+!   Hamiltonian:
+!   $$ \hat{H}\rightarrow\hat{H}+\frac{g_s}{4c}{\bf B}\cdot\boldsymbol\sigma. $$
+!
+! !REVISION HISTORY:
+!   Created April 2018 (Mueller)
+!EOP
+!BOC
 implicit none
 ! local variables
 integer idm,is,ias
@@ -50,20 +75,22 @@ do idm=1,3
   end do
 ! solve Poisson's equation in the muffin-tin to find the A-field
   call genzvclmt(nrmt,nrmti,nrmtmax,rlmt,wprmt,npmtmax,zrhomt,zvclmt)
-  zrhoir(:)=rvfir(:,idm)
+  zrhoir(1:ngtot)=rvfir(1:ngtot,idm)
 ! solve in the entire unit cell
-  call zpotcoul(nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg,ngvec, &
-   jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
+  call zpotcoul(0,nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg, &
+   ngvec,jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
 ! convert muffin-tin A-field to real spherical harmonics
   do ias=1,natmtot
     is=idxis(ias)
     call ztorfmt(nrmt(is),nrmti(is),zvclmt(:,ias),rvfmt(:,ias,idm))
   end do
 ! store the real part of the interstitial A-field
-  rvfir(:,idm)=dble(zvclir(:))
+  rvfir(1:ngtot,idm)=dble(zvclir(1:ngtot))
 end do
 ! compute the curl of A to obtain the dipole B-field
 call curlrvf(rvfmt,rvfir,bdmt,bdir)
+! scale dipole B-field if required (by scaling the prefactor)
+cb=cb*bdipscf
 ! add to the Kohn-Sham field
 do idm=1,3
   do ias=1,natmtot
@@ -79,9 +106,10 @@ do idm=1,3
   end do
 end do
 do idm=1,3
-  bsir(:,idm)=bsir(:,idm)+cb*bdir(:,idm)*cfunir(:)
+  bsir(1:ngtot,idm)=bsir(1:ngtot,idm)+cb*bdir(1:ngtot,idm)
 end do
 deallocate(rvfmt,rvfir)
 deallocate(zrhomt,zrhoir,zvclmt,zvclir)
 end subroutine
+!EOC
 
