@@ -17,7 +17,7 @@ character(256) fext
 ! allocatable arrays
 real(8), allocatable :: w(:),wt(:),jt(:,:)
 real(8), allocatable :: f1(:),f2(:)
-complex(8), allocatable :: bec(:,:)
+complex(8), allocatable :: becw(:,:)
 ! initialise universal variables
 call init0
 ! store original parameters
@@ -31,8 +31,8 @@ tshift=.false.
 call gentimes
 ! allocate local arrays
 allocate(w(nwplot),wt(ntimes),jt(3,ntimes))
-allocate(f1(ntimes),f2(ntimes),bec(nwplot,3))
-! generate energy grid (always non-negative)
+allocate(f1(ntimes),f2(ntimes),becw(nwplot,3))
+! generate frequency grid (always non-negative)
 w1=max(wplot(1),0.d0)
 w2=max(wplot(2),w1)
 t1=(w2-w1)/dble(nwplot)
@@ -57,7 +57,7 @@ if (isph == 0) then
   afieldc(:)=afieldc0(:)
   tshift=tshift0
   trdatdv=.false.
-  deallocate(w,wt,jt,f1,f2,bec)
+  deallocate(w,wt,jt,f1,f2,becw)
   return
 end if
 if (mp_mpi) then
@@ -106,7 +106,7 @@ do i=1,3
     end do
     t1=dot_product(wt(:),f1(:))
     t2=dot_product(wt(:),f2(:))
-    bec(iw,i)=t0*cmplx(t1,t2,8)
+    becw(iw,i)=t0*cmplx(t1,t2,8)
   end do
 end do
 ! static and nuclear charge
@@ -120,11 +120,11 @@ if (mp_mpi) then
       t2=0.d0
     end if
     do iw=1,nwplot
-      write(80,'(2G18.10)') w(iw),dble(bec(iw,i))+t2
+      write(80,'(2G18.10)') w(iw),dble(becw(iw,i))+t2
     end do
     write(80,*)
     do iw=1,nwplot
-      write(80,'(2G18.10)') w(iw),aimag(bec(iw,i))
+      write(80,'(2G18.10)') w(iw),aimag(becw(iw,i))
     end do
     write(80,*)
   end do
@@ -135,7 +135,7 @@ call mpi_barrier(mpicom,ierror)
 ! write test file if required and return
 if (test) then
   call writetest(478,'dynamical Born effective charge',nv=nwplot,tol=1.d-2, &
-   zva=bec)
+   zva=becw)
   return
 end if
 goto 10
