@@ -32,17 +32,16 @@ if (nspecies <= 0) return
 rmtp(1:nspecies)=rmt(1:nspecies)
 ! restore original muffin-tin radii read from species files if required
 if (trmt0) rmt(1:nspecies)=rmt0(1:nspecies)
-10 continue
+do
 ! find the minimum distance between muffin-tin surfaces
-call mtdmin(is,js,dmin)
-! adjust muffin-tin radii if required
-if (dmin < rmtdelta-1.d-4) then
+  call mtdmin(is,js,dmin)
+  if (dmin > rmtdelta-1.d-4) exit
+! adjust muffin-tin radii
   t1=rmt(is)+rmt(js)
   t2=(t1+dmin-rmtdelta)/t1
   rmt(is)=rmt(is)*t2
   if (is /= js) rmt(js)=rmt(js)*t2
-  goto 10
-end if
+end do
 do is=1,nspecies
   if (rmt(is) < 0.1d0) then
     write(*,*)
