@@ -13,8 +13,7 @@ real(8) w1,w2,t0,t1,t2
 complex(8) eta,z1,z2
 character(256) fname
 ! allocatable arrays
-real(8), allocatable :: w(:),wt(:),jt(:,:)
-real(8), allocatable :: f1(:),f2(:)
+real(8), allocatable :: w(:),wt(:),jt(:,:),f1(:),f2(:)
 complex(8), allocatable :: ew(:,:),jw(:,:),eps(:)
 ! initialise global variables
 call init0
@@ -103,8 +102,7 @@ do i=1,3
       else
         z1=0.d0
       end if
-      z1=fourpi*cmplx(-aimag(z1),dble(z1),8)
-      z1=z1/(w(iw)+eta)
+      z1=fourpi*zi*z1/(w(iw)+eta)
       if (i == j) z1=z1+1.d0
       eps(iw)=z1
     end do
