@@ -13,15 +13,13 @@ complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 complex(8), intent(out) :: dapwalm(ngkmax,apwordmax,lmmaxapw)
 ! local variables
 integer is,l,lm,io,igp
-complex(8) z1
 ! take derivative with respect to atomic displacement
 is=idxis(ias)
 do l=0,lmaxapw
   do lm=l**2+1,(l+1)**2
     do io=1,apword(l,is)
       do igp=1,ngp
-        z1=apwalm(igp,io,lm,ias)
-        dapwalm(igp,io,lm)=vgpc(ip,igp)*cmplx(-aimag(z1),dble(z1),8)
+        dapwalm(igp,io,lm)=vgpc(ip,igp)*zi*apwalm(igp,io,lm,ias)
       end do
     end do
   end do
