@@ -81,9 +81,7 @@ open(63,file='ELIASHBERG_IA.OUT',form='FORMATTED')
 open(64,file='ELIASHBERG_GAP_T.OUT',form='FORMATTED')
 open(65,file='ELIASHBERG_GAP_RA.OUT',form='FORMATTED')
 open(66,file='ELIASHBERG_Z_RA.OUT',form='FORMATTED')
-write(62,'("+------------------------------+")')
-write(62,'("|     Eliashberg equations     |")')
-write(62,'("+------------------------------+")')
+call writebox(62,"Eliashberg equations")
 write(62,*)
 write(62,'("Temperature range : ",2G18.10)') tmin,tmax
 write(62,'("Number of temperature steps : ",I6)') ntemp
@@ -120,6 +118,7 @@ do itemp=1,ntemp
   call holdthd(4*nwf+1,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(t1,sm,i) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
   do m=-2*nwf,2*nwf
     t1=(t0*dble(2*m))**2
