@@ -14,6 +14,7 @@ use moddelf
 implicit none
 ! local variables
 logical exist
+character(64) str
 ! initialise MPI execution environment
 call mpi_init(ierror)
 ! duplicate mpi_comm_world
@@ -25,13 +26,12 @@ call mpi_comm_rank(mpicom,lp_mpi,ierror)
 ! determine if the local process is the master
 if (lp_mpi == 0) then
   mp_mpi=.true.
-  write(*,*)
-  write(*,'("+---------------------------------+")')
-  write(*,'("| Elk code version ",I1.1,".",I1.1,".",I2.2," started |")') version
-  write(*,'("+---------------------------------+")')
+  write(str,'("Elk code version ",I0,".",I0,".",I0," started")') version
+  call writebox(6,trim(str))
 else
   mp_mpi=.false.
 end if
+10 continue
 ! read input files
 call readinput
 ! initialise OpenMP variables
@@ -88,27 +88,21 @@ else
 end if
 ! perform the tasks
 do itask=1,ntasks
-! synchronise MPI processes
-  call mpi_barrier(mpicom,ierror)
   task=tasks(itask)
   if (mp_mpi) then
-    write(*,*)
-    write(*,'("+-----------------------+")')
-    write(*,'("| Current task : ",I6," |")') task
-    write(*,'("+-----------------------+")')
+    write(str,'("Current task : ",I0)') task
+    call writebox(6,trim(str))
   end if
 ! increment the batch variables if required
   if (batch) call batchdv
 ! check if task can be run with MPI
   if (lp_mpi > 0) then
-    if (any(task == [0,1,2,3,5,15,16,28,29,61,62,63,110,120,121,125,135,136, &
-     162,170,180,185,200,201,205,208,240,241,270,271,300,320,330,331,350,351, &
-     371,372,373,380,390,420,421,440,460,461,462,463,471,478,600,610,620,640, &
-     700,701])) then
-      continue
-    else
+    if (all(task /= [0,1,2,3,5,15,16,28,29,61,62,63,110,120,121,125,135,136, &
+     162,170,180,185,200,201,202,205,208,209,240,241,270,271,300,320,330,331, &
+     350,351,352,371,372,373,380,390,420,421,440,460,461,462,463,471,478,600, &
+     610,620,640,680,700,701,720])) then
       write(*,'("Info(elk): MPI process ",I6," idle for task ",I6)') lp_mpi,task
-      cycle
+      goto 20
     end if
   end if
 ! write task to VARIABLES.OUT
@@ -148,7 +142,7 @@ do itask=1,ntasks
     call vecplot
   case(91,92,93)
     call dbxcplot
-  case(100,101)
+  case(100,101,103,104)
     call fermisurf
   case(102)
     call fermisurfbxsf
@@ -266,8 +260,14 @@ do itask=1,ntasks
     call gwbandstr
   case(640)
     call gwdmat
+  case(680)
+    call tdhfc
   case(700,701)
     call gndstulr
+  case(710)
+    call writedosu
+  case(720)
+    call bandstrulr
   case(731,732,733)
     call rhouplot
   case(741,742,743)
@@ -282,20 +282,29 @@ do itask=1,ntasks
   end select
 ! reset the OpenMP thread variables
   call omp_reset
+20 continue
+! synchronise MPI processes
+  call mpi_barrier(mpicom,ierror)
+! check if a restart is requested
+  call checkrst
+  if (trestart) then
+    if (mp_mpi) then
+      write(*,*)
+      write(*,'("Restarting Elk")')
+    end if
+    goto 10
+  end if
 end do
 if (mp_mpi) then
   call delfile('RUNNING')
-  write(*,*)
-  write(*,'("+------------------+")')
-  write(*,'("| Elk code stopped |")')
-  write(*,'("+------------------+")')
+  call writebox(6,"Elk code stopped")
 end if
 ! terminate MPI execution environment
 call mpi_finalize(ierror)
 end program
 
 !BOI
-! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 9.6.8}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
+! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 10.2.4}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
 ! !AUTHORS: {\sc J. K. Dewhurst, S. Sharma} \\ {\sc L. Nordstr\"{o}m, F. Cricchio, O. Gr\aa n\"{a}s} \\ {\sc E. K. U. Gross}
 ! !AFFILIATION:
 ! !INTRODUCTION: Introduction
@@ -465,13 +474,12 @@ end program
 !   before running the code.
 !
 !   \subsection{Linking with the Libxc functional library}
-!   Libxc is the ETSF library of exchange-correlation functionals. Elk can use
-!   the complete set of LDA and GGA functionals available in Libxc as well as
-!   the potential-only metaGGA's. In order to enable this, first download and
-!   compile Libxc version 6. This should have produced the files {\tt libxc.a}
-!   and {\tt libxcf90.a}. Copy these files and the file {\tt libxcf90.f90} from
-!   the Libxc {\tt src} directory to the {\tt elk/src} directory and then
-!   uncomment the lines indicated for Libxc in the file {\tt elk/make.inc}. Once
+!   Libxc is a library of exchange-correlation functionals. Elk can use the
+!   complete set of LDA and GGA functionals available in Libxc as well as some
+!   meta-GGAs. In order to enable this, first download and compile Libxc. This
+!   should have produced the files {\tt libxc.a} and {\tt libxcf03.a} in the
+!   Libxc directory {\tt src/.libs}. Copy these to the {\tt elk/src} directory
+!   and then uncomment the lines indicated for Libxc in {\tt elk/make.inc}. Once
 !   this is done, run {\tt make clean} followed by {\tt make}. To select a
 !   particular functional of Libxc, use the block
 !   \begin{verbatim}
@@ -480,7 +488,7 @@ end program
 !   \end{verbatim}
 !   where {\tt nx} and {\tt nc} are, respectively, the numbers of the exchange
 !   and correlation functionals in the Libxc library. See the file
-!   {\tt elk/src/libxcf90.f90} for a list of the functionals and their
+!   {\tt elk/src/libxcf03.f90} for a list of the functionals and their
 !   associated numbers.
 !
 !   \subsection{Running the code}
@@ -1385,6 +1393,14 @@ end program
 !   This sets the maximum length for the ${\bf G}+{\bf k}$ vectors, defined as
 !   {\tt rgkmax} divided by the average muffin-tin radius. See {\tt isgkmax}.
 !
+!   \block{rmtall}{
+!   {\tt rmtall} & muffin-tin radius for all species & real & $-1.0$}
+!   If {\tt rmtall} is positive then all muffin-tin radii are set to this value.
+!
+!   \block{rmtscf}{
+!   {\tt rmtscf} & muffin-tin radius scaling factor & real & $1.0$}
+!   All muffin-tin radii read from the species files are scaled by this factor.
+!
 !   \block{rotavec}{
 !   {\tt axang} & axis-angle representation of lattice vector rotation &
 !    real(4) & $(0.0,0.0,0.0,0.0)$}
@@ -1554,7 +1570,7 @@ end program
 !   151/2/3 & 1/2/3D plot of
 !    ${\bf m}({\bf r})\times{\bf B}_{\rm xc}({\bf r})$. \\
 !   160 & Calculates the total exchange-correlation spin-torque acting on the
-!    system: $\boldsymbol{\tau}=\int d^3r\, {\bf m}({\bf r})\times
+!    system: $\boldsymbol\tau=\int d^3r\, {\bf m}({\bf r})\times
 !    {\bf B}_{\rm xc}({\bf r}).$ \\
 !   162 & 2D scanning-tunneling microscopy (STM) image. \\
 !   170 & Writes the electron momentum density to {\tt EMD.OUT}. \\
