@@ -46,9 +46,9 @@ integer k1,k2,k3,k4
 integer l1,l2,m1,m2
 integer info,nthd,nts
 real(8) v(3),vl,vu
-real(8) t1,t2,t3,t4
+real(8) s1,t1,t2,t3,t4
 real(8) ts0,ts1
-complex(8) h1,h2,o1,o2,z1
+complex(8) z1
 ! automatic arrays
 logical tr(nlotot),tp(nlotot)
 integer idx(nlotot),s(nlotot)
@@ -58,7 +58,7 @@ complex(8) zp(nlotot)
 ! allocatable arrays
 real(8), allocatable :: rh(:),ro(:),rv(:,:)
 call timesec(ts0)
-tp(:)=.false.
+tp(1:nlotot)=.false.
 i=0
 do is=1,nspecies
   do ia=1,natoms(is)
@@ -66,7 +66,7 @@ do is=1,nspecies
     ja=ieqatom(ia,is,2)
     jas=idxas(ja,is)
 ! residual phase factor
-    v(:)=atposc(:,ia,is)+atposc(:,ja,is)
+    v(1:3)=atposc(1:3,ia,is)+atposc(1:3,ja,is)
     t1=0.5d0*(vpc(1)*v(1)+vpc(2)*v(2)+vpc(3)*v(3))
     z1=cmplx(cos(t1),sin(t1),8)
     do ilo=1,nlorb(is)
@@ -136,21 +136,22 @@ do j=1,ngp
 end do
 ! <APW|H|lo>
 do m1=1,nlotot
-  j1=ngp+m1
-  j2=ngp+idx(m1)
-  do i=1,ngp
-    k1=i+(j1-1)*nmatp
-    k2=i+(j2-1)*nmatp
-    h1=h(k1); h2=h(k2)
-    if (tp(m1)) then
-      h1=h1*zp(m1); h2=h2*zp(m1)
-    end if
+  j1=(ngp+m1-1)*nmatp
+  j2=(ngp+idx(m1)-1)*nmatp
+  z1=zp(m1); s1=s(m1)
+  if (tp(m1)) then
     if (tr(m1)) then
-      rh(k1)=dble(h1)+s(m1)*dble(h2)
+      rh(j1+1:j1+ngp)=dble(h(j1+1:j1+ngp)*z1)+s1*dble(h(j2+1:j2+ngp)*z1)
     else
-      rh(k1)=aimag(h1)+s(m1)*aimag(h2)
+      rh(j1+1:j1+ngp)=aimag(h(j1+1:j1+ngp)*z1)+s1*aimag(h(j2+1:j2+ngp)*z1)
     end if
-  end do
+  else
+    if (tr(m1)) then
+      rh(j1+1:j1+ngp)=dble(h(j1+1:j1+ngp))+s1*dble(h(j2+1:j2+ngp))
+    else
+      rh(j1+1:j1+ngp)=aimag(h(j1+1:j1+ngp))+s1*aimag(h(j2+1:j2+ngp))
+    end if
+  end if
 end do
 ! <lo|H|lo>
 do m1=1,nlotot
@@ -183,21 +184,22 @@ do j=1,ngp
 end do
 ! <APW|O|lo>
 do m1=1,nlotot
-  j1=ngp+m1
-  j2=ngp+idx(m1)
-  do i=1,ngp
-    k1=i+(j1-1)*nmatp
-    k2=i+(j2-1)*nmatp
-    o1=o(k1); o2=o(k2)
-    if (tp(m1)) then
-      o1=o1*zp(m1); o2=o2*zp(m1)
-    end if
+  j1=(ngp+m1-1)*nmatp
+  j2=(ngp+idx(m1)-1)*nmatp
+  z1=zp(m1); s1=s(m1)
+  if (tp(m1)) then
     if (tr(m1)) then
-      ro(k1)=dble(o1)+s(m1)*dble(o2)
+      ro(j1+1:j1+ngp)=dble(o(j1+1:j1+ngp)*z1)+s1*dble(o(j2+1:j2+ngp)*z1)
     else
-      ro(k1)=aimag(o1)+s(m1)*aimag(o2)
+      ro(j1+1:j1+ngp)=aimag(o(j1+1:j1+ngp)*z1)+s1*aimag(o(j2+1:j2+ngp)*z1)
     end if
-  end do
+  else
+    if (tr(m1)) then
+      ro(j1+1:j1+ngp)=dble(o(j1+1:j1+ngp))+s1*dble(o(j2+1:j2+ngp))
+    else
+      ro(j1+1:j1+ngp)=aimag(o(j1+1:j1+ngp))+s1*aimag(o(j2+1:j2+ngp))
+    end if
+  end if
 end do
 ! <lo|O|lo>
 do m1=1,nlotot
