@@ -45,8 +45,8 @@ end if
 call spline(n,x,f,cf)
 select case(m)
 case(:-1)
-  sm=0.d0
   g(1)=0.d0
+  sm=0.d0
   do i=1,n-1
     dx=x(i+1)-x(i)
     sm=sm+dx*(f(i) &
@@ -56,13 +56,13 @@ case(:-1)
     g(i+1)=sm
   end do
 case(1)
-  g(:)=cf(1,:)
+  g(1:n)=cf(1,1:n)
 case(2)
-  g(:)=2.d0*cf(2,:)
+  g(1:n)=2.d0*cf(2,1:n)
 case(3)
-  g(:)=6.d0*cf(3,:)
+  g(1:n)=6.d0*cf(3,1:n)
 case(4:)
-  g(:)=0.d0
+  g(1:n)=0.d0
 end select
 end subroutine
 !EOC
