@@ -36,13 +36,13 @@ logical done(natmmax)
 real(8) vr(nrmtmax),fr(nrmtmax)
 real(8) p0(nrmtmax,apwordmax),p1(nrmtmax),p1s(apwordmax)
 real(8) q0(nrmtmax),q1(nrmtmax),ep0(nrmtmax,apwordmax)
-! external functions
-real(8), external :: splint
+! loop over species
 do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
   iro=nri+1
   done(:)=.false.
+! loop over atoms
   do ia=1,natoms(is)
     if (done(ia)) cycle
     ias=idxas(ia,is)
@@ -62,7 +62,7 @@ do is=1,nspecies
         ep0(1:nr,io)=e*p0(1:nr,io)
 ! normalise radial functions
         fr(1:nr)=p0(1:nr,io)**2
-        t1=splint(nr,rlmt(:,1,is),fr)
+        t1=dot_product(wrmt(1:nr,is),fr(1:nr))
         t1=1.d0/sqrt(abs(t1))
         p0(1:nr,io)=t1*p0(1:nr,io)
         p1s(io)=t1*p1(nr)
@@ -70,15 +70,14 @@ do is=1,nspecies
 ! subtract linear combination of previous vectors
         do jo=1,io-1
           fr(1:nr)=p0(1:nr,io)*p0(1:nr,jo)
-          t1=-splint(nr,rlmt(:,1,is),fr)
+          t1=-dot_product(wrmt(1:nr,is),fr(1:nr))
           p0(1:nr,io)=p0(1:nr,io)+t1*p0(1:nr,jo)
           p1s(io)=p1s(io)+t1*p1s(jo)
           ep0(1:nr,io)=ep0(1:nr,io)+t1*ep0(1:nr,jo)
         end do
 ! normalise radial functions again
         fr(1:nr)=p0(1:nr,io)**2
-        t1=splint(nr,rlmt(:,1,is),fr)
-        t1=abs(t1)
+        t1=abs(dot_product(wrmt(1:nr,is),fr(1:nr)))
         if (t1 < 1.d-25) then
           write(*,*)
           write(*,'("Error(genapwfr): degenerate APW radial functions")')
@@ -99,8 +98,8 @@ do is=1,nspecies
           apwfr(ir,1,io,l,ias)=t1*p0(ir,io)
           apwfr(ir,2,io,l,ias)=t1*ep0(ir,io)
         end do
-! derivative at the muffin-tin surface
-        apwdfr(io,l,ias)=(p1s(io)-p0(nr,io)*t1)*t1
+! derivative at the muffin-tin surface multiplied by R_MT²/2
+        apwdfr(io,l,ias)=(p1s(io)*rmt(is)-p0(nr,io))/2.d0
       end do
     end do
     done(ia)=.true.
