@@ -7,15 +7,16 @@ subroutine gengvc
 use modmain
 implicit none
 ! local variables
-integer ig,i1,i2,i3,j1,j2,j3
+integer ig,ifg,n1
+integer i1,i2,i3,j1,j2,j3
 real(8) gk2
 ! find optimal grid size for |G| < 2 gkmax
 gk2=2.d0*gkmax+epslat
-ngdgc(:)=int(gk2*sqrt(avec(1,:)**2+avec(2,:)**2+avec(3,:)**2)/pi)+1
-! find next largest FFT-compatible grid size (radices 2, 3, 5 and 7)
-call nfftifc(4,ngdgc(1))
-call nfftifc(4,ngdgc(2))
-call nfftifc(4,ngdgc(3))
+ngdgc(1:3)=int(gk2*sqrt(avec(1,1:3)**2+avec(2,1:3)**2+avec(3,1:3)**2)/pi)+1
+! find next largest FFT-compatible grid size
+call nfftifc(npfftgc,ngdgc(1))
+call nfftifc(npfftgc,ngdgc(2))
+call nfftifc(npfftgc,ngdgc(3))
 ! total number of points in coarse grid
 ngtc=ngdgc(1)*ngdgc(2)*ngdgc(3)
 ! find the number of vectors with |G| < 2 gkmax
@@ -26,9 +27,15 @@ do ig=2,ngvec
     exit
   end if
 end do
+! number of complex FFT elements for real-complex transforms
+n1=ngdgc(1)/2+1
+nfgrzc=n1*ngdgc(2)*ngdgc(3)
 ! Fourier transform index
 if (allocated(igfc)) deallocate(igfc)
 allocate(igfc(ngvc))
+if (allocated(igrzfc)) deallocate(igrzfc)
+allocate(igrzfc(nfgrzc))
+igrzfc(1:nfgrzc)=ngvc+1
 do ig=1,ngvc
   i1=ivg(1,ig)
   i2=ivg(2,ig)
@@ -49,6 +56,11 @@ do ig=1,ngvc
     j3=ngdgc(3)+i3
   end if
   igfc(ig)=j3*ngdgc(2)*ngdgc(1)+j2*ngdgc(1)+j1+1
+! map from real-complex FFT index to G-vector index
+  if (i1 >= 0) then
+    ifg=j3*ngdgc(2)*n1+j2*n1+j1+1
+    igrzfc(ifg)=ig
+  end if
 end do
 end subroutine
 
