@@ -12,11 +12,11 @@ implicit none
 integer, intent(in) :: ik0
 complex(8), intent(out) :: h(nstulr,nstulr)
 ! local variables
-integer ik,ist,jst,ispn,nthd
+integer ik,ist,jst,ispn,idm,nthd
 integer ikpa,jkpa,iq,ifq,ngk0,igk
 integer i1,i2,i3,j1,j2,j3,i,j
 ! automatic arrays
-complex(8) vmat(nstsv,nstsv)
+complex(8) zvir(ngtc),zbir(ngtc,ndmag),vmat(nstsv,nstsv)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(4), allocatable :: wfmt(:,:,:,:),wfir(:,:,:),wfgk(:,:,:)
@@ -38,18 +38,19 @@ call genwfsv_sp(.false.,.true.,nstsv,[0],ngridg,igfft,ngk0,igkig(:,1,ik), &
  apwalm,evecfv,evecsv,wfmt,ngk0,wfgk)
 deallocate(apwalm,evecfv,evecsv)
 ! determine the interstitial wavefunctions in real-space (without 1/sqrt(omega))
-allocate(wfir(ngtot,nspinor,nstsv))
+allocate(wfir(ngtc,nspinor,nstsv))
 call holdthd(nstsv,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(ispn,igk) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ist=1,nstsv
   do ispn=1,nspinor
-    wfir(:,ispn,ist)=0.e0
+    wfir(1:ngtc,ispn,ist)=0.e0
     do igk=1,ngk0
-      wfir(igfft(igkig(igk,1,ik)),ispn,ist)=wfgk(igk,ispn,ist)
+      wfir(igfc(igkig(igk,1,ik)),ispn,ist)=wfgk(igk,ispn,ist)
     end do
-    call cfftifc(3,ngridg,1,wfir(:,ispn,ist))
+    call cfftifc(3,ngdgc,1,wfir(:,ispn,ist))
   end do
 end do
 !$OMP END PARALLEL DO
@@ -57,23 +58,31 @@ call freethd(nthd)
 ! generate the matrix elements for all Q-vectors
 call holdthd(nfqrz,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(vmat,iq,i,j,ikpa,jkpa) &
-!$OMP PRIVATE(j1,j2,j3,ist,jst,i1,i2,i3) &
+!$OMP PRIVATE(zvir,zbir,vmat) &
+!$OMP PRIVATE(iq,idm,ikpa,jkpa,j1,j2,j3) &
+!$OMP PRIVATE(ist,jst,i,j,i1,i2,i3) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ifq=1,nfqrz
   iq=iqrzf(ifq)
+! multiply long-range interstitial potential by characteristic function and
+! convert to coarse grid
+  call zfirftoc(vsqir(:,ifq),zvir)
   if (spinpol) then
-    call genzvbmatk(vsqmt(:,:,ifq),vsqir(:,ifq),bsqmt(:,:,:,ifq), &
-     bsqir(:,:,ifq),ngk0,igkig(:,1,ik),wfmt,wfir,wfgk,vmat)
+! convert interstitial magnetic field to coarse grid
+    do idm=1,ndmag
+      call zfirftoc(bsqir(:,idm,ifq),zbir(:,idm))
+    end do
+! calculate matrix elements for this Q-vector
+    call genzvbmatk(vsqmt(:,:,ifq),zvir,bsqmt(:,:,:,ifq),zbir,ngk0, &
+     igkig(:,1,ik),wfmt,wfir,wfgk,vmat)
   else
-    call genzvmatk(vsqmt(:,:,ifq),vsqir(:,ifq),ngk0,igkig(:,1,ik),wfmt,wfir, &
-     wfgk,vmat)
+    call genzvmatk(vsqmt(:,:,ifq),zvir,ngk0,igkig(:,1,ik),wfmt,wfir,wfgk,vmat)
   end if
-  j=0
   do jkpa=1,nkpa
     j1=ivq(1,jkpa); j2=ivq(2,jkpa); j3=ivq(3,jkpa)
     do jst=1,nstsv
-      j=j+1
+      j=(jkpa-1)*nstsv+jst
       do ikpa=1,jkpa-1
         i=(ikpa-1)*nstsv+1
         i1=ivq(1,ikpa)-j1; i2=ivq(2,ikpa)-j2; i3=ivq(3,ikpa)-j3
@@ -83,8 +92,7 @@ do ifq=1,nfqrz
         else if (ivqiq(-i1,-i2,-i3) == iq) then
 ! otherwise use conjugate transpose
           do ist=1,nstsv
-            h(i,j)=conjg(vmat(jst,ist))
-            i=i+1
+            h(i+ist-1,j)=conjg(vmat(jst,ist))
           end do
         end if
       end do
@@ -105,7 +113,7 @@ do ist=1,nstsv
   h(ist,ist)=h(ist,ist)+evalsv(ist,ik)
 end do
 allocate(hdb(nstsv,nstsv,2:nkpa))
-call gethdbulr(ik0,hdb)
+call hdbulrk(ik0,hdb)
 do ikpa=2,nkpa
   i=(ikpa-1)*nstsv
   do jst=1,nstsv
