@@ -29,6 +29,7 @@ do ias=1,natmtot
 end do
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ik=1,nkpt
 ! distribute among MPI processes
@@ -45,6 +46,7 @@ end do
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is,nrc,nrci,i) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -57,18 +59,18 @@ end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
 ! symmetrise the current density
-call symrvf(.false.,.true.,nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npmtmax, &
- jrmt,ngtot,jrir)
+call symrvf(.false.,.true.,nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,nfgrzc,igfc, &
+ igrzfc,npmtmax,jrmt,ngtot,jrir)
 ! convert muffin-tin and interstitial current density from coarse to fine grids
 call holdthd(6,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do i=1,3
   call rfmtctof(jrmt(:,:,i))
 end do
 !$OMP END DO NOWAIT
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do i=1,3
   call rfirctof(jrir(:,i),jrir(:,i))
 end do
