@@ -89,20 +89,20 @@ do ist=1,nst
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
 ! Fourier transform to real-space and conjugate
-    zfft1(:)=0.d0
+    zfft1(1:ngtc)=0.d0
     do igk=1,ngk(jspn,ik)
       ifg=igfc(igkig(igk,jspn,ik))
       zfft1(ifg)=wfgk(igk,ispn,ist)
     end do
     call zfftifc(3,ngdgc,1,zfft1)
-    zfft1(:)=conjg(zfft1(:))
+    zfft1(1:ngtc)=conjg(zfft1(1:ngtc))
     do i=1,3
 ! compute the gradient of the wavefunction
-      zfft2(:)=0.d0
+      zfft2(1:ngtc)=0.d0
       do igk=1,ngk(jspn,ik)
         ifg=igfc(igkig(igk,jspn,ik))
         z1=wfgk(igk,ispn,ist)
-        zfft2(ifg)=vgkc(i,igk,jspn,ik)*cmplx(-aimag(z1),dble(z1),8)
+        zfft2(ifg)=vgkc(i,igk,jspn,ik)*zi*z1
       end do
       call zfftifc(3,ngdgc,1,zfft2)
 !$OMP CRITICAL(currentk_)
