@@ -14,25 +14,25 @@ integer n1,iq,ifq,ir
 real(8) v(3)
 ! allocatable arrays
 real(8), allocatable :: vkl0(:,:),vkc0(:,:),wkpt0(:)
-! find next largest FFT-compatible Q-point grid size (radices 2, 3, 5 and 7)
-call nfftifc(4,ngridq(1))
-call nfftifc(4,ngridq(2))
-call nfftifc(4,ngridq(3))
+! find next largest FFT-compatible Q-point grid size
+call nfftifc(npfftq,ngridq(1))
+call nfftifc(npfftq,ngridq(2))
+call nfftifc(npfftq,ngridq(3))
 ! total number of Q-points
 nqpt=ngridq(1)*ngridq(2)*ngridq(3)
 ! number of complex FFT elements for real-complex transforms
 n1=ngridq(1)/2+1
 nfqrz=n1*ngridq(2)*ngridq(3)
 ! integer grid intervals for the Q-points
-intq(1,:)=ngridq(:)/2-ngridq(:)+1
-intq(2,:)=ngridq(:)/2
+intq(1,1:3)=ngridq(1:3)/2-ngridq(1:3)+1
+intq(2,1:3)=ngridq(1:3)/2
 ! kappa-point grid should be half the Q-point grid
-ngridkpa(:)=(ngridq(:)+1)/2
+ngridkpa(1:3)=(ngridq(1:3)+1)/2
 ! number of kappa-points
 nkpa=ngridkpa(1)*ngridkpa(2)*ngridkpa(3)
 ! integer grid intervals for the kappa-points
-intkpa(1,:)=ngridkpa(:)/2-ngridkpa(:)+1
-intkpa(2,:)=ngridkpa(:)/2
+intkpa(1,1:3)=ngridkpa(1:3)/2-ngridkpa(1:3)+1
+intkpa(2,1:3)=ngridkpa(1:3)/2
 ! allocate global Q-point arrays
 if (allocated(ivq)) deallocate(ivq)
 allocate(ivq(3,nqpt))
@@ -78,8 +78,8 @@ end do
 ! ensure the first point is the zero vector
 do iq=1,nkpa
   if ((ivq(1,iq) == 0).and.(ivq(2,iq) == 0).and.(ivq(3,iq) == 0)) then
-    ivq(:,iq)=ivq(:,1)
-    ivq(:,1)=0
+    ivq(1:3,iq)=ivq(1:3,1)
+    ivq(1:3,1)=0
     exit
   end if
 end do
@@ -88,12 +88,12 @@ do iq=1,nqpt
 ! map from (i1,i2,i3) to Q-vector index
   ivqiq(i1,i2,i3)=iq
 ! Q-vector in Cartesian coordinates
-  vqc(:,iq)=dble(i1)*bvecu(:,1) &
-           +dble(i2)*bvecu(:,2) &
-           +dble(i3)*bvecu(:,3)
+  vqc(1:3,iq)=dble(i1)*bvecu(1:3,1) &
+             +dble(i2)*bvecu(1:3,2) &
+             +dble(i3)*bvecu(1:3,3)
 ! Q-vector in (unit cell) lattice coordinates
   call r3mv(binv,vqc(:,iq),vql(:,iq))
-  where(abs(vql(:,iq)) < epslat) vql(:,iq)=0.d0
+  where(abs(vql(1:3,iq)) < epslat) vql(1:3,iq)=0.d0
 end do
 ! set up Fourier transform index
 do iq=1,nqpt
@@ -136,10 +136,16 @@ do i3=0,ngridq(3)-1
     end do
   end do
 end do
+! allocate the k-point weight array for band structure calculation
+if (task == 720) then
+  if (allocated(wkpt)) deallocate(wkpt)
+  allocate(wkpt(nkpt))
+  wkpt(1:nkpt)=1.d0
+end if
 ! store the existing k-point and weight arrays
 allocate(vkl0(3,nkpt),vkc0(3,nkpt),wkpt0(nkpt))
-vkl0(:,1:nkpt)=vkl(:,1:nkpt)
-vkc0(:,1:nkpt)=vkc(:,1:nkpt)
+vkl0(1:3,1:nkpt)=vkl(1:3,1:nkpt)
+vkc0(1:3,1:nkpt)=vkc(1:3,1:nkpt)
 wkpt0(1:nkpt)=wkpt(1:nkpt)
 ! number of k+kappa-points
 nkpt0=nkpt
@@ -151,8 +157,8 @@ ik=0
 do ik0=1,nkpt0
   do ikpa=1,nkpa
     ik=ik+1
-    vkl(:,ik)=vkl0(:,ik0)+vql(:,ikpa)
-    vkc(:,ik)=vkc0(:,ik0)+vqc(:,ikpa)
+    vkl(1:3,ik)=vkl0(1:3,ik0)+vql(1:3,ikpa)
+    vkc(1:3,ik)=vkc0(1:3,ik0)+vqc(1:3,ikpa)
     wkpt(ik)=wkpt0(ik0)/dble(nkpa)
   end do
 end do
