@@ -37,11 +37,10 @@ integer ipiv(nplorb)
 real(8) vr(nrmtmax),fr(nrmtmax)
 real(8) p0(nrmtmax,lorbordmax),p1(nrmtmax)
 real(8) q0(nrmtmax),q1(nrmtmax),ep0(nrmtmax,lorbordmax)
-real(8) p0s(nrmtmax,nlomax),ep0s(nrmtmax,nlomax)
-real(8) xa(nplorb),ya(nplorb)
-real(8) a(nplorb,nplorb),b(nplorb)
+real(8) p0c(nrmtmax,nlomax),ep0c(nrmtmax,nlomax)
+real(8) xa(nplorb),ya(nplorb),a(nplorb,nplorb),b(nplorb)
 ! external functions
-real(8), external :: splint,polynm
+real(8), external :: polynm
 do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
@@ -66,7 +65,7 @@ do is=1,nspecies
         ep0(1:nr,jo)=e*p0(1:nr,jo)
 ! normalise radial functions
         fr(1:nr)=p0(1:nr,jo)**2
-        t1=splint(nr,rlmt(:,1,is),fr)
+        t1=dot_product(wrmt(1:nr,is),fr(1:nr))
         t1=1.d0/sqrt(abs(t1))
         p0(1:nr,jo)=t1*p0(1:nr,jo)
         ep0(1:nr,jo)=t1*ep0(1:nr,jo)
@@ -81,46 +80,45 @@ do is=1,nspecies
         end do
       end do
 ! set up the target vector
-      b(:)=0.d0
+      b(1:nplorb)=0.d0
       b(lorbord(ilo,is))=1.d0
       call dgesv(lorbord(ilo,is),1,a,nplorb,ipiv,b,nplorb,info)
       if (info /= 0) goto 10
-! generate linear superposition of radial functions
-      p0s(:,ilo)=0.d0
-      ep0s(:,ilo)=0.d0
+! generate linear combination of radial functions
+      p0c(1:nr,ilo)=0.d0
+      ep0c(1:nr,ilo)=0.d0
       do io=1,lorbord(ilo,is)
         t1=b(io)
-        p0s(1:nr,ilo)=p0s(1:nr,ilo)+t1*p0(1:nr,io)
-        ep0s(1:nr,ilo)=ep0s(1:nr,ilo)+t1*ep0(1:nr,io)
+        p0c(1:nr,ilo)=p0c(1:nr,ilo)+t1*p0(1:nr,io)
+        ep0c(1:nr,ilo)=ep0c(1:nr,ilo)+t1*ep0(1:nr,io)
       end do
 ! normalise radial functions
-      fr(1:nr)=p0s(1:nr,ilo)**2
-      t1=splint(nr,rlmt(:,1,is),fr)
+      fr(1:nr)=p0c(1:nr,ilo)**2
+      t1=dot_product(wrmt(1:nr,is),fr(1:nr))
       t1=1.d0/sqrt(abs(t1))
-      p0s(1:nr,ilo)=t1*p0s(1:nr,ilo)
-      ep0s(1:nr,ilo)=t1*ep0s(1:nr,ilo)
+      p0c(1:nr,ilo)=t1*p0c(1:nr,ilo)
+      ep0c(1:nr,ilo)=t1*ep0c(1:nr,ilo)
 ! subtract linear combination of previous local-orbitals with same l
       do jlo=1,ilo-1
         if (lorbl(jlo,is) == l) then
-          fr(1:nr)=p0s(1:nr,ilo)*p0s(1:nr,jlo)
-          t1=-splint(nr,rlmt(:,1,is),fr)
-          p0s(1:nr,ilo)=p0s(1:nr,ilo)+t1*p0s(1:nr,jlo)
-          ep0s(1:nr,ilo)=ep0s(1:nr,ilo)+t1*ep0s(1:nr,jlo)
+          fr(1:nr)=p0c(1:nr,ilo)*p0c(1:nr,jlo)
+          t1=-dot_product(wrmt(1:nr,is),fr(1:nr))
+          p0c(1:nr,ilo)=p0c(1:nr,ilo)+t1*p0c(1:nr,jlo)
+          ep0c(1:nr,ilo)=ep0c(1:nr,ilo)+t1*ep0c(1:nr,jlo)
         end if
       end do
 ! normalise radial functions again
-      fr(1:nr)=p0s(1:nr,ilo)**2
-      t1=splint(nr,rlmt(:,1,is),fr)
-      t1=abs(t1)
+      fr(1:nr)=p0c(1:nr,ilo)**2
+      t1=abs(dot_product(wrmt(1:nr,is),fr(1:nr)))
       if (t1 < 1.d-25) goto 10
       t1=1.d0/sqrt(t1)
-      p0s(1:nr,ilo)=t1*p0s(1:nr,ilo)
-      ep0s(1:nr,ilo)=t1*ep0s(1:nr,ilo)
+      p0c(1:nr,ilo)=t1*p0c(1:nr,ilo)
+      ep0c(1:nr,ilo)=t1*ep0c(1:nr,ilo)
 ! divide by r and store in global array
       do ir=1,nr
         t1=rlmt(ir,-1,is)
-        lofr(ir,1,ilo,ias)=t1*p0s(ir,ilo)
-        lofr(ir,2,ilo,ias)=t1*ep0s(ir,ilo)
+        lofr(ir,1,ilo,ias)=t1*p0c(ir,ilo)
+        lofr(ir,2,ilo,ias)=t1*ep0c(ir,ilo)
       end do
     end do
     done(ia)=.true.
