@@ -58,7 +58,7 @@ complex(8), external :: zdotc
 ! coefficient of spin-orbit coupling
 cso=1.d0/(4.d0*solsc**2)
 ! zero the momentum matrix elements array
-pmat(:,:,:)=0.d0
+pmat(1:nstsv,1:nstsv,1:3)=0.d0
 !---------------------------------!
 !     muffin-tin contribution     !
 !---------------------------------!
@@ -92,19 +92,17 @@ do is=1,nspecies
         end do
 ! compute i σ x (grad V(r)) φ(r)
         do i=1,npc
-          z1=zfmt1(i,1)
-          z1=cmplx(-aimag(z1),dble(z1),8)
-          z2=zfmt1(i,2)
-          z2=cmplx(-aimag(z2),dble(z2),8)
+          z1=zi*zfmt1(i,1)
+          z2=zi*zfmt1(i,2)
           z11=gvmt(i,1)*z1; z12=gvmt(i,1)*z2
           z21=gvmt(i,2)*z1; z22=gvmt(i,2)*z2
           z31=gvmt(i,3)*z1; z32=gvmt(i,3)*z2
-          zfmt2(i,1,1)=cmplx(aimag(z32),-dble(z32),8)-z21
-          zfmt2(i,1,2)=cmplx(-aimag(z31),dble(z31),8)+z22
+          zfmt2(i,1,1)=zmi*z32-z21
+          zfmt2(i,1,2)=zi*z31+z22
           zfmt2(i,2,1)=z11-z32
           zfmt2(i,2,2)=-z12-z31
-          zfmt2(i,3,1)=cmplx(-aimag(z12),dble(z12),8)+z22
-          zfmt2(i,3,2)=cmplx(aimag(z11),-dble(z11),8)+z21
+          zfmt2(i,3,1)=zi*z12+z22
+          zfmt2(i,3,2)=zmi*z11+z21
         end do
 ! convert to spherical harmonics and add to wavefunction gradient
         do ispn=1,nspinor
@@ -117,7 +115,7 @@ do is=1,nspecies
       do i=1,3
         do ispn=1,nspinor
 ! apply the radial integral weights
-          call zfmtwr(nrc,nrci,wrcmt(:,is),gwfmt(:,i,ispn))
+          call zfmtwr(nrc,nrci,wr2cmt(:,is),gwfmt(:,i,ispn))
 ! compute the overlaps
           do ist=1,jst
             pmat(ist,jst,i)=pmat(ist,jst,i)+zdotc(npc,wfmt(:,ias,ispn,ist),1, &
@@ -135,17 +133,17 @@ do jst=1,nstsv
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
 ! compute the gradient
-    gwfir(:,:)=0.d0
+    gwfir(1:ngtc,1:3)=0.d0
     do igp=1,ngp(jspn)
       ifg=igfc(igpig(igp,jspn))
       z1=wfgp(igp,ispn,jst)
-      gwfir(ifg,1:3)=vgpc(1:3,igp,jspn)*cmplx(-aimag(z1),dble(z1),8)
+      gwfir(ifg,1:3)=vgpc(1:3,igp,jspn)*zi*z1
     end do
     do i=1,3
 ! Fourier transform to real-space
       call zfftifc(3,ngdgc,1,gwfir(:,i))
 ! multiply by coarse characteristic function
-      gwfir(:,i)=gwfir(:,i)*cfrc(:)
+      gwfir(1:ngtc,i)=gwfir(1:ngtc,i)*cfrc(1:ngtc)
 ! Fourier transform back to G-space
       call zfftifc(3,ngdgc,-1,gwfir(:,i))
     end do
@@ -165,8 +163,7 @@ end do
 do i=1,3
   do jst=1,nstsv
     do ist=1,jst-1
-      z1=pmat(ist,jst,i)
-      z1=cmplx(aimag(z1),-dble(z1),8)
+      z1=zmi*pmat(ist,jst,i)
       pmat(ist,jst,i)=z1
       pmat(jst,ist,i)=conjg(z1)
     end do
