@@ -63,10 +63,8 @@ subroutine genppts(tfbz,nsym,sym,ngridp,npptnr,epslat,bvec,boxl,nppt,ipvip, &
 implicit none
 ! arguments
 logical, intent(in) :: tfbz
-integer, intent(in) :: nsym,sym(3,3,*)
-integer, intent(in) :: ngridp(3),npptnr
-real(8), intent(in) :: epslat
-real(8), intent(in) :: bvec(3,3),boxl(3,0:3)
+integer, intent(in) :: nsym,sym(3,3,*),ngridp(3),npptnr
+real(8), intent(in) :: epslat,bvec(3,3),boxl(3,0:3)
 integer, intent(out) :: nppt
 integer, intent(out) :: ipvip(0:ngridp(1)-1,0:ngridp(2)-1,0:ngridp(3)-1)
 integer, intent(out) :: ipvipnr(0:ngridp(1)-1,0:ngridp(2)-1,0:ngridp(3)-1)
@@ -92,9 +90,9 @@ if (npptnr /= ngridp(1)*ngridp(2)*ngridp(3)) then
   stop
 end if
 ! box vector matrix
-b(:,1)=boxl(:,1)-boxl(:,0)
-b(:,2)=boxl(:,2)-boxl(:,0)
-b(:,3)=boxl(:,3)-boxl(:,0)
+b(1:3,1)=boxl(1:3,1)-boxl(1:3,0)
+b(1:3,2)=boxl(1:3,2)-boxl(1:3,0)
+b(1:3,3)=boxl(1:3,3)-boxl(1:3,0)
 ! weight of each non-reduced p-point
 wpptnr=1.d0/dble(ngridp(1)*ngridp(2)*ngridp(3))
 ip=0
@@ -106,7 +104,7 @@ do i3=0,ngridp(3)-1
     do i1=0,ngridp(1)-1
       v1(1)=dble(i1)/dble(ngridp(1))
       call r3mv(b,v1,v2)
-      v2(:)=v2(:)+boxl(:,0)
+      v2(1:3)=v2(1:3)+boxl(1:3,0)
 ! map vector components to [0,1)
       call r3frac(epslat,v2)
       if (nsym > 1) then
@@ -123,7 +121,7 @@ do i3=0,ngridp(3)-1
 ! add new point to back of set
               ipvipnr(i1,i2,i3)=jp
               ivp(1,jp)=i1; ivp(2,jp)=i2; ivp(3,jp)=i3
-              vpl(:,jp)=v2(:)
+              vpl(1:3,jp)=v2(1:3)
               wppt(jp)=0.d0
               jp=jp-1
               goto 10
@@ -136,7 +134,7 @@ do i3=0,ngridp(3)-1
       ipvip(i1,i2,i3)=ip
       ipvipnr(i1,i2,i3)=ip
       ivp(1,ip)=i1; ivp(2,ip)=i2; ivp(3,ip)=i3
-      vpl(:,ip)=v2(:)
+      vpl(1:3,ip)=v2(1:3)
       wppt(ip)=wpptnr
 10 continue
     end do
