@@ -48,6 +48,8 @@ if (allocated(rlmt)) deallocate(rlmt)
 allocate(rlmt(nrmtmax,-lmaxo-1:lmaxo+2,nspecies))
 if (allocated(wrmt)) deallocate(wrmt)
 allocate(wrmt(nrmtmax,nspecies))
+if (allocated(wr2mt)) deallocate(wr2mt)
+allocate(wr2mt(nrmtmax,nspecies))
 if (allocated(wprmt)) deallocate(wprmt)
 allocate(wprmt(4,nrmtmax,nspecies))
 if (allocated(wcrmt)) deallocate(wcrmt)
@@ -72,8 +74,8 @@ do is=1,nspecies
   end do
 ! determine the weights for spline integration on the fine radial mesh
   call wsplint(nr,rsp(:,is),wrmt(:,is))
-! multiply by r²
-  wrmt(1:nr,is)=wrmt(1:nr,is)*rlmt(1:nr,2,is)
+! multiply by r² and store in separate array
+  wr2mt(1:nr,is)=wrmt(1:nr,is)*rlmt(1:nr,2,is)
 ! determine the weights for partial integration on fine radial mesh
   call wsplintp(nr,rsp(:,is),wprmt(:,:,is))
 ! determine the weights for the spline coefficients
@@ -87,8 +89,8 @@ if (allocated(rcmt)) deallocate(rcmt)
 allocate(rcmt(nrcmtmax,nspecies))
 if (allocated(rlcmt)) deallocate(rlcmt)
 allocate(rlcmt(nrcmtmax,-lmaxo-1:lmaxo+2,nspecies))
-if (allocated(wrcmt)) deallocate(wrcmt)
-allocate(wrcmt(nrcmtmax,nspecies))
+if (allocated(wr2cmt)) deallocate(wr2cmt)
+allocate(wr2cmt(nrcmtmax,nspecies))
 if (allocated(wprcmt)) deallocate(wprcmt)
 allocate(wprcmt(4,nrcmtmax,nspecies))
 if (allocated(wcrcmt)) deallocate(wcrcmt)
@@ -97,9 +99,8 @@ do is=1,nspecies
   t1=fracinr*rmt(is)
   nrmti(is)=1
   nrcmti(is)=1
-  irc=0
   do ir=1,nrmt(is),lradstp
-    irc=irc+1
+    irc=(ir-1)/lradstp+1
     rcmt(irc,is)=rsp(ir,is)
     if (rsp(ir,is) < t1) then
       nrmti(is)=ir
@@ -108,17 +109,16 @@ do is=1,nspecies
   end do
 ! store rˡ on the coarse radial mesh
   do l=-lmaxo-1,lmaxo+2
-    irc=0
     do ir=1,nrmt(is),lradstp
-      irc=irc+1
+      irc=(ir-1)/lradstp+1
       rlcmt(irc,l,is)=rlmt(ir,l,is)
     end do
   end do
 ! determine the weights for spline integration on the coarse radial mesh
   nrc=nrcmt(is)
-  call wsplint(nrc,rcmt(:,is),wrcmt(:,is))
+  call wsplint(nrc,rcmt(:,is),wr2cmt(:,is))
 ! multiply by r²
-  wrcmt(1:nrc,is)=wrcmt(1:nrc,is)*rlcmt(1:nrc,2,is)
+  wr2cmt(1:nrc,is)=wr2cmt(1:nrc,is)*rlcmt(1:nrc,2,is)
 ! determine the weights for partial integration on coarse radial mesh
   call wsplintp(nrc,rcmt(:,is),wprcmt(:,:,is))
 ! determine the weights for the spline coefficients
