@@ -30,6 +30,7 @@ end do
 tauir(1:ngtc,1:nspinor)=0.d0
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ik=1,nkpt
 ! distribute among MPI processes
@@ -61,9 +62,10 @@ if (spinpol) then
   rfir(1:ngtc)=tauir(1:ngtc,1)+tauir(1:ngtc,2)
   rvfir(1:ngtc,1:ndmag-1)=0.d0
   rvfir(1:ngtc,ndmag)=tauir(1:ngtc,1)-tauir(1:ngtc,2)
-  call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npcmtmax,rfmt,rfir)
-  call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npcmtmax,&
-   rvfmt,ngtc,rvfir)
+  call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,nfgrzc,igfc,igrzfc,npcmtmax, &
+   rfmt,rfir)
+  call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,nfgrzc,igfc, &
+   igrzfc,npcmtmax,rvfmt,ngtc,rvfir)
   do ias=1,natmtot
     is=idxis(ias)
     npc=npcmt(is)
@@ -75,7 +77,8 @@ if (spinpol) then
   deallocate(rvfmt,rvfir,rfir)
 else
 ! spin-unpolarised case
-  call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npmtmax,taumt,tauir)
+  call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,nfgrzc,igfc,igrzfc,npmtmax, &
+   taumt,tauir)
 end if
 ! convert muffin-tin tau from coarse to fine radial mesh
 do ispn=1,nspinor
