@@ -80,11 +80,11 @@ do ist=1,nst
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
     do i=1,3
-      zfft(:)=0.d0
+      zfft(1:ngtc)=0.d0
       do igk=1,ngk(jspn,ik)
         ifg=igfc(igkig(igk,jspn,ik))
         z1=wfgp(igk,ispn,ist)
-        zfft(ifg)=vgkc(i,igk,jspn,ik)*cmplx(-aimag(z1),dble(z1),8)
+        zfft(ifg)=vgkc(i,igk,jspn,ik)*zi*z1
       end do
       call zfftifc(3,ngdgc,1,zfft)
 !$OMP CRITICAL(gentauk_2)
