@@ -18,14 +18,14 @@ if (wmaxgw <= 0.d0) then
   do ik=1,nkpt
     call getevalsv(filext,ik,vkl(:,ik),evalsv(:,ik))
   end do
-  de=maxval(abs(evalsv(:,:)-efermi))
+  de=maxval(abs(evalsv(1:nstsv,1:nkpt)-efermi))
   wmaxgw=abs(wmaxgw)*de
 end if
 ! number of Matsubara frequencies
 t1=pi*t0
 nwgw=2*nint(wmaxgw/t1)
 nwgw=max(nwgw,2)
-call nfftifc(4,nwgw)
+call nfftifc(npfftw,nwgw)
 ! determine integer ranges for grid
 intwgw(1)=nwgw/2-nwgw+1
 intwgw(2)=nwgw/2
@@ -42,7 +42,7 @@ do iw=intwgw(1),intwgw(2)
   iwfft(iw)=jw+1
   wgw(iw)=dble(iw)*t1
 end do
-n=minval(abs(intwgw(:)))
+n=minval(abs(intwgw(1:2)))
 if (n == 0) then
   write(*,*)
   write(*,'("Error(genwgw): not enough Matsubara frequencies")')
