@@ -56,7 +56,7 @@ do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
     else
       zfft2(ifg)=0.d0
     end if
@@ -81,7 +81,7 @@ do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvec) then
-      zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
     else
       zfft2(ifg)=0.d0
     end if
@@ -98,7 +98,7 @@ do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
     else
       zfft2(ifg)=0.d0
     end if
@@ -123,7 +123,7 @@ do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvec) then
-      zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
     else
       zfft2(ifg)=0.d0
     end if
@@ -145,7 +145,7 @@ do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvec) then
-      zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(zfft1(ifg)),dble(zfft1(ifg)),8)
+      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
     else
       zfft2(ifg)=0.d0
     end if
