@@ -34,6 +34,7 @@ implicit none
 logical twrite
 integer ik,nmix,nwork
 real(8) dv,etp,de,timetot
+character(64) str
 ! allocatable arrays
 real(8), allocatable :: work(:)
 ! initialise global variables
@@ -121,17 +122,12 @@ tlast=.false.
 etp=0.d0
 ! begin the self-consistent loop
 if (mp_mpi) then
-  write(60,*)
-  write(60,'("+------------------------------+")')
-  write(60,'("| Self-consistent loop started |")')
-  write(60,'("+------------------------------+")')
+  call writebox(60,"Self-consistent loop started")
 end if
 do iscl=1,maxscl
   if (mp_mpi) then
-    write(60,*)
-    write(60,'("+--------------------+")')
-    write(60,'("| Loop number : ",I4," |")') iscl
-    write(60,'("+--------------------+")')
+    write(str,'("Loop number : ",I0)') iscl
+    call writebox(60,trim(str))
   end if
   if (iscl >= maxscl) then
     if (mp_mpi) then
@@ -217,6 +213,11 @@ do iscl=1,maxscl
     bfieldc(:)=bfieldc(:)*reducebf
     bfcmt(:,:,:)=bfcmt(:,:,:)*reducebf
   end if
+! compute the paramagnetic current density and total current if required
+  if (tjr.and.tlast) then
+    call genjpr
+    call genjtot
+  end if
 ! compute the energy components
   call energy
   if (mp_mpi) then
@@ -320,10 +321,7 @@ end do
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 if (mp_mpi) then
-  write(60,*)
-  write(60,'("+------------------------------+")')
-  write(60,'("| Self-consistent loop stopped |")')
-  write(60,'("+------------------------------+")')
+  call writebox(60,"Self-consistent loop stopped")
 ! write density and potentials to file only if maxscl > 1
   if (maxscl > 1) then
     call writestate
@@ -337,16 +335,12 @@ if (tforce) then
 ! output forces to INFO.OUT
   if (mp_mpi) call writeforces(60)
 end if
-! compute the paramagnetic current density and total current if required
-if (tjr) then
-  call genjpr
-  call genjtot
-  if (mp_mpi) then
-    write(60,*)
-    write(60,'("Total paramagnetic current per unit cell")')
-    write(60,'(3G18.10)') jtot
-    write(60,'(" magnitude : ",G18.10)') jtotm
-  end if
+! output the paramagnetic current
+if (tjr.and.mp_mpi) then
+  write(60,*)
+  write(60,'("Total paramagnetic current per unit cell")')
+  write(60,'(3G18.10)') jtot
+  write(60,'(" magnitude : ",G18.10)') jtotm
 end if
 ! total time used
 timetot=timeinit+timemat+timefv+timesv+timerho+timepot+timefor
@@ -366,10 +360,6 @@ if (mp_mpi) then
     write(60,'(" force calculation",T40,": ",F12.2)') timefor
   end if
   write(60,'(" total",T40,": ",F12.2)') timetot
-  write(60,*)
-  write(60,'("+----------------------------+")')
-  write(60,'("| Elk version ",I1.1,".",I1.1,".",I2.2," stopped |")') version
-  write(60,'("+----------------------------+")')
 ! close the INFO.OUT file
   close(60)
 ! close the TOTENERGY.OUT file
@@ -389,19 +379,7 @@ if (mp_mpi) then
 ! close the RESIDUAL.OUT file
   if (xctype(1) < 0) close(69)
 ! write to VARIABLES.OUT if required
-  if (wrtvars) then
-    call writevars('engytot',rv=engytot)
-    call writevars('fermidos',rv=fermidos)
-    call writevars('bandgap',nv=2,rva=bandgap)
-    if (spinpol) then
-      call writevars('momtot',nv=ndmag,rva=momtot)
-      call writevars('momtotm',rv=momtotm)
-      call writevars('mommt',nv=3*natmtot,rva=mommt)
-    end if
-    if (tforce) then
-      call writevars('forcetot',nv=3*natmtot,rva=forcetot)
-    end if
-  end if
+  if (wrtvars) call writegsvars
 end if
 deallocate(work)
 wrtdsk=wrtdsk0
