@@ -6,10 +6,11 @@
 !BOP
 ! !ROUTINE: gridsize
 ! !INTERFACE:
-subroutine gridsize(avec,gmaxvr,ngridg,ngtot,intgv)
+subroutine gridsize(avec,gmaxvr,npfft,ngridg,ngtot,intgv)
 ! !INPUT/OUTPUT PARAMETERS:
 !   avec   : lattice vectors (in,real(3,3))
 !   gmaxvr : G-vector cut-off (in,real)
+!   npfft  : number of prime factors to use for the FFT (in,integer)
 !   ngridg : G-vector grid sizes (out,integer(3))
 !   ngtot  : total number of G-vectors (out,integer)
 !   intgv  : integer grid intervals for each direction (out,integer(2,3))
@@ -28,15 +29,16 @@ subroutine gridsize(avec,gmaxvr,ngridg,ngtot,intgv)
 implicit none
 ! arguments
 real(8), intent(in) :: avec(3,3),gmaxvr
+integer, intent(in) :: npfft
 integer, intent(out) :: ngridg(3),ngtot,intgv(2,3)
 ! local variables
 real(8), parameter :: pi=3.1415926535897932385d0
 ! find optimal grid size for potential and density
-ngridg(:)=int(gmaxvr*sqrt(avec(1,:)**2+avec(2,:)**2+avec(3,:)**2)/pi)+1
-! find next largest FFT-compatible grid size (radices 2, 3, 5 and 7)
-call nfftifc(4,ngridg(1))
-call nfftifc(4,ngridg(2))
-call nfftifc(4,ngridg(3))
+ngridg(1:3)=int(gmaxvr*sqrt(avec(1,1:3)**2+avec(2,1:3)**2+avec(3,1:3)**2)/pi)+1
+! find next largest FFT-compatible grid size
+call nfftifc(npfft,ngridg(1))
+call nfftifc(npfft,ngridg(2))
+call nfftifc(npfft,ngridg(3))
 if ((ngridg(1) <= 0).or.(ngridg(2) <= 0).or.(ngridg(3) <= 0)) then
   write(*,*)
   write(*,'("Error(gridsize): invalid ngridg : ",3I8)') ngridg
@@ -46,8 +48,8 @@ end if
 ! total number of points in grid
 ngtot=ngridg(1)*ngridg(2)*ngridg(3)
 ! determine integer ranges for grid
-intgv(1,:)=ngridg(:)/2-ngridg(:)+1
-intgv(2,:)=ngridg(:)/2
+intgv(1,1:3)=ngridg(1:3)/2-ngridg(1:3)+1
+intgv(2,1:3)=ngridg(1:3)/2
 end subroutine
 !EOC
 
