@@ -15,17 +15,16 @@ complex(8), intent(inout) :: hq(*)
 integer io,jo,i
 integer l0,l1,l2,l3
 integer lm1,lm3,lma,lmb
-real(8) t0,t1
+real(8) t1
 complex(8) z1
 ! automatic arrays
 complex(8) y(ngp),a(lmoapw(is),ngpq),b(lmoapw(is),ngp)
-t0=0.5d0*rmt(is)**2
 i=0
 do l1=0,lmaxapw
   do lm1=l1**2+1,(l1+1)**2
     do io=1,apword(l1,is)
       i=i+1
-      t1=t0*apwfr(nrmt(is),1,io,l1,ias)
+      t1=apwfr(nrmt(is),1,io,l1,ias)
       y(:)=0.d0
       do l3=0,lmaxapw
         if (mod(l1+l3,2) == 0) then; l0=0; else; l0=1; end if
