@@ -74,7 +74,7 @@ else
     end if
   end do
 end if
-if (any(task == [20,21,22,23])) then
+if (any(task == [20,21,22,23,720])) then
 ! generate k-points along a path for band structure plots
   call plotpt1d(bvec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
   nkpt=npp1d
@@ -83,7 +83,7 @@ if (any(task == [20,21,22,23])) then
   if (allocated(vkc)) deallocate(vkc)
   allocate(vkc(3,nkpt))
   do ik=1,nkpt
-    vkl(:,ik)=vplp1d(:,ik)
+    vkl(1:3,ik)=vplp1d(1:3,ik)
     call r3mv(bvec,vkl(:,ik),vkc(:,ik))
   end do
   nkptnr=nkpt
@@ -129,7 +129,7 @@ else
   boxl(2,2)=boxl(2,2)+1.d0
   boxl(3,3)=boxl(3,3)+1.d0
 ! k-point set and box for Fermi surface plots
-  if (any(task == [100,101,102])) then
+  if (any(task == [100,101,102,103,104])) then
     ngridk(:)=np3d(:)
     if (task /= 102) boxl(:,:)=vclp3d(:,:)
   end if
@@ -163,7 +163,7 @@ else
     call writevars('wkpt',nv=nkpt,rva=wkpt)
   end if
 end if
-if (any(task == [700,701,731,732,733,741,742,743,771,772,773])) then
+if (any(task == [700,701,710,720,731,732,733,741,742,743,771,772,773])) then
 ! generate ultracell reciprocal lattice vectors if required
   call reciplat(avecu,bvecu,omegau,omegabzu)
 ! generate the kappa, k+kappa and Q-points if required
@@ -198,16 +198,16 @@ if (allocated(sfacgk)) deallocate(sfacgk)
 allocate(sfacgk(ngkmax,natmtot,nspnfv,nppt))
 do ik=1,nppt
   do jspn=1,nspnfv
-    vl(:)=vkl(:,ik)
-    vc(:)=vkc(:,ik)
+    vl(1:3)=vkl(1:3,ik)
+    vc(1:3)=vkc(1:3,ik)
 ! spin-spiral case
     if (spinsprl) then
       if (jspn == 1) then
-        vl(:)=vl(:)+0.5d0*vqlss(:)
-        vc(:)=vc(:)+0.5d0*vqcss(:)
+        vl(1:3)=vl(1:3)+0.5d0*vqlss(1:3)
+        vc(1:3)=vc(1:3)+0.5d0*vqcss(1:3)
       else
-        vl(:)=vl(:)-0.5d0*vqlss(:)
-        vc(:)=vc(:)-0.5d0*vqcss(:)
+        vl(1:3)=vl(1:3)-0.5d0*vqlss(1:3)
+        vc(1:3)=vc(1:3)-0.5d0*vqcss(1:3)
       end if
     end if
 ! generate the G+k-vectors
@@ -336,7 +336,7 @@ if (allocated(evalsv)) deallocate(evalsv)
 allocate(evalsv(nstsv,nkpt))
 if (allocated(occsv)) deallocate(occsv)
 allocate(occsv(nstsv,nkpt))
-occsv(:,:)=0.d0
+occsv(1:nstsv,1:nkpt)=0.d0
 ! allocate overlap and Hamiltonian integral arrays
 if (allocated(oalo)) deallocate(oalo)
 allocate(oalo(apwordmax,nlomax,natmtot))
