@@ -104,7 +104,7 @@ do is=1,nspecies
     t1=1.d0
     do io=2,omax
       t1=t1*gpc(igp)
-      djl(:,io,igp)=t1*djl(:,io,igp)
+      djl(0:lmaxapw,io,igp)=t1*djl(0:lmaxapw,io,igp)
     end do
   end do
 ! loop over atoms
