@@ -43,8 +43,7 @@ implicit none
 integer, intent(in) :: iscl
 real(8), intent(in) :: beta0,betamax
 integer, intent(in) :: n
-real(8), intent(inout) :: nu(n),mu(n)
-real(8), intent(inout) :: beta(n),f(n)
+real(8), intent(inout) :: nu(n),mu(n),beta(n),f(n)
 real(8), intent(out) :: d
 ! local variables
 integer i
@@ -52,9 +51,9 @@ real(8) t1
 if (n <= 0) return
 ! initialise mixer
 if (iscl <= 0) then
-  mu(:)=nu(:)
-  f(:)=0.d0
-  beta(:)=beta0
+  mu(1:n)=nu(1:n)
+  f(1:n)=0.d0
+  beta(1:n)=beta0
   d=1.d0
   return
 end if
