@@ -14,8 +14,7 @@ real(8), intent(inout) :: f(n,2),df(n,msd)
 real(8), intent(inout) :: u(n,msd),a(msd,msd)
 real(8), intent(out) :: d
 ! local variables
-integer jc,kp,kc
-integer k,l,m
+integer jc,kp,kc,k,l,m
 integer info,nthd
 real(8) t1
 ! automatic arrays
@@ -37,12 +36,12 @@ if (msd < 2) then
 end if
 ! initialise mixer
 if (iscl <= 0) then
-  mu(:,1)=nu(:)
-  mu(:,2)=nu(:)
-  f(:,1)=0.d0
-  df(:,1)=0.d0
-  u(:,1)=0.d0
-  a(:,:)=0.d0
+  mu(1:n,1)=nu(1:n)
+  mu(1:n,2)=nu(1:n)
+  f(1:n,1)=0.d0
+  df(1:n,1)=0.d0
+  u(1:n,1)=0.d0
+  a(1:msd,1:msd)=0.d0
   d=1.d0
   return
 end if
@@ -54,23 +53,23 @@ jc=mod(iscl,m)+1
 kp=mod(iscl-1,2)+1
 ! current index modulo 2
 kc=mod(iscl,2)+1
-f(:,kc)=nu(:)-mu(:,kp)
-d=sum(f(:,kc)**2)
+f(1:n,kc)=nu(1:n)-mu(1:n,kp)
+d=sum(f(1:n,kc)**2)
 d=sqrt(d/dble(n))
-df(:,jc)=f(:,kc)-f(:,kp)
-t1=norm2(df(:,jc))
+df(1:n,jc)=f(1:n,kc)-f(1:n,kp)
+t1=norm2(df(1:n,jc))
 if (t1 > 1.d-8) t1=1.d0/t1
-df(:,jc)=t1*df(:,jc)
-u(:,jc)=alpha*df(:,jc)+t1*(mu(:,kp)-mu(:,kc))
+df(1:n,jc)=t1*df(1:n,jc)
+u(1:n,jc)=alpha*df(1:n,jc)+t1*(mu(1:n,kp)-mu(1:n,kc))
 call holdthd(2*m,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do k=1,m
   c(k)=ddot(n,df(1,k),1,f(1,kc),1)
 end do
 !$OMP END DO NOWAIT
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do k=1,m
   a(k,jc)=ddot(n,df(1,k),1,df(1,jc),1)
   a(jc,k)=a(k,jc)
@@ -78,7 +77,7 @@ end do
 !$OMP END DO
 !$OMP END PARALLEL
 call freethd(nthd)
-beta(:,:)=a(:,:)
+beta(1:msd,1:msd)=a(1:msd,1:msd)
 do k=1,m
   beta(k,k)=beta(k,k)+w0**2
 end do
@@ -97,11 +96,11 @@ do l=1,m
     gamma(l)=gamma(l)+c(k)*beta(k,l)
   end do
 end do
-nu(:)=mu(:,kp)+alpha*f(:,kc)
+nu(1:n)=mu(1:n,kp)+alpha*f(1:n,kc)
 do l=1,m
   t1=-gamma(l)
-  nu(:)=nu(:)+t1*u(:,l)
+  nu(1:n)=nu(1:n)+t1*u(1:n,l)
 end do
-mu(:,kc)=nu(:)
+mu(1:n,kc)=nu(1:n)
 end subroutine
 
