@@ -17,7 +17,7 @@ real(8) t0,t1
 if (n <= 0) return
 ! initialise mixer
 if (iscl <= 0) then
-  mu(:)=nu(:)
+  mu(1:n)=nu(1:n)
   d=1.d0
   return
 end if
