@@ -28,11 +28,11 @@ select case(abs(fxctype(1)))
 case(0,1)
 ! f_xc = 0
   if (present(fxcuu).and.present(fxcud).and.present(fxcdd)) then
-    fxcuu(:)=0.d0
-    fxcud(:)=0.d0
-    fxcdd(:)=0.d0
+    fxcuu(1:n)=0.d0
+    fxcud(1:n)=0.d0
+    fxcdd(1:n)=0.d0
   else if (present(fxc)) then
-    fxc(:)=0.d0
+    fxc(1:n)=0.d0
   else
     goto 10
   end if
@@ -45,9 +45,9 @@ case(3)
   else if (present(rho).and.present(fxc)) then
 ! divide spin-unpolarised density into up and down
     allocate(ra(n,4))
-    ra(:,1)=0.5d0*rho(:)
+    ra(1:n,1)=0.5d0*rho(1:n)
     call fxc_pwca(n,ra(:,1),ra(:,1),ra(:,2),ra(:,3),ra(:,4))
-    fxc(:)=0.5d0*(ra(:,2)+ra(:,3))
+    fxc(1:n)=0.5d0*(ra(1:n,2)+ra(1:n,3))
     deallocate(ra)
   else
     goto 10
