@@ -48,6 +48,16 @@ complex(8), allocatable :: expqmt(:,:,:)
 !---------------------------------------------------!
 !     ultra long-range densities and potentials     !
 !---------------------------------------------------!
+! R-dependent density and magnetisation
+real(8), allocatable :: rhormt(:,:,:),rhorir(:,:)
+real(8), allocatable :: magrmt(:,:,:,:),magrir(:,:,:)
+! muffin-tin charges each R-vector
+real(8), allocatable :: chgmtru(:,:)
+! muffin-tin, interstitial and total moments for each R-vector
+real(8), allocatable :: mommtru(:,:,:),momirru(:,:),momtotru(:,:)
+! Q-dependent density and magnetisation
+complex(8), allocatable :: rhoqmt(:,:,:),rhoqir(:,:)
+complex(8), allocatable :: magqmt(:,:,:,:),magqir(:,:,:)
 ! trdvclr is .true. if the real-space external Coulomb potential should be read
 ! in from file
 logical trdvclr
@@ -59,15 +69,10 @@ complex(8), allocatable :: bfcq(:,:)
 complex(8), allocatable :: bfcmtq(:,:,:)
 ! electric field vector in Cartesian coordinates
 real(8) efielduc(3)
-! R-dependent density and magnetisation
-real(8), allocatable :: rhormt(:,:,:),rhorir(:,:)
-real(8), allocatable :: magrmt(:,:,:,:),magrir(:,:,:)
-! muffin-tin charges and moments for each R-vector
-real(8), allocatable :: chgmtru(:,:)
-real(8), allocatable :: mommtru(:,:,:)
-! Q-dependent density and magnetisation
-complex(8), allocatable :: rhoqmt(:,:,:),rhoqir(:,:)
-complex(8), allocatable :: magqmt(:,:,:,:),magqir(:,:,:)
+! if tbdipu is .true. then the spin dipole-dipole interaction is included
+logical tbdipu
+! Q-dependent magnetic dipole field
+complex(8), allocatable :: bdipq(:,:)
 ! Q-dependent Kohn-Sham potential and magnetic field
 complex(8), allocatable, target :: vsbsq(:)
 complex(8), pointer, contiguous :: vsqmt(:,:,:),vsqir(:,:)
