@@ -5,9 +5,6 @@
 
 module modvars
 
-use modmain
-use moddftu
-
 ! if wrtvars is .true. then variables are written to VARIABLES.OUT
 logical wrtvars
 ! if batch is .true. then Elk will run in batch mode
