@@ -97,8 +97,7 @@ subroutine xcifc(xctype,n,tempa,rho,rhoup,rhodn,grho,gup,gdn,g2rho,g2up,g2dn, &
 !BOC
 implicit none
 ! mandatory arguments
-integer, intent(in) :: xctype(3)
-integer, intent(in) :: n
+integer, intent(in) :: xctype(3),n
 ! optional arguments
 real(8), optional, intent(in) :: tempa
 real(8), optional, intent(in) :: rho(n),rhoup(n),rhodn(n)
@@ -131,14 +130,14 @@ end if
 select case(abs(xctype(1)))
 case(1)
 ! No density-derived exchange-correlation energy or potential
-  if (present(ex)) ex(:)=0.d0
-  if (present(ec)) ec(:)=0.d0
-  if (present(vx)) vx(:)=0.d0
-  if (present(vc)) vc(:)=0.d0
-  if (present(vxup)) vxup(:)=0.d0
-  if (present(vxdn)) vxdn(:)=0.d0
-  if (present(vcup)) vcup(:)=0.d0
-  if (present(vcdn)) vcdn(:)=0.d0
+  if (present(ex)) ex(1:n)=0.d0
+  if (present(ec)) ec(1:n)=0.d0
+  if (present(vx)) vx(1:n)=0.d0
+  if (present(vc)) vc(1:n)=0.d0
+  if (present(vxup)) vxup(1:n)=0.d0
+  if (present(vxdn)) vxdn(1:n)=0.d0
+  if (present(vcup)) vcup(1:n)=0.d0
+  if (present(vcdn)) vcdn(1:n)=0.d0
 case(2)
 ! Perdew-Zunger parameterisation of Ceperley-Alder electron gas
 ! J. Perdew and A. Zunger, Phys. Rev. B 23, 5048 (1981)
@@ -162,7 +161,7 @@ case(3)
    .and.present(vc)) then
 ! divide spin-unpolarised density into up and down
     allocate(ra(n,2))
-    ra(:,1)=0.5d0*rho(:)
+    ra(1:n,1)=0.5d0*rho(1:n)
     call xc_pwca(n,ra,ra,ex,ec,vx,ra(:,2),vc,ra(:,2))
     deallocate(ra)
   else
@@ -175,8 +174,8 @@ case(4)
    .and.present(vc)) then
     call xc_xalpha(n,rho,ex,vx)
 ! set correlation energy and potential to zero
-    ec(:)=0.d0
-    vc(:)=0.d0
+    ec(1:n)=0.d0
+    vc(1:n)=0.d0
   else
     goto 10
   end if
@@ -192,7 +191,7 @@ case(5)
    .and.present(vc)) then
 ! divide spin-unpolarised density into up and down
     allocate(ra(n,2))
-    ra(:,1)=0.5d0*rho(:)
+    ra(1:n,1)=0.5d0*rho(1:n)
     call xc_vbh(n,ra,ra,ex,ec,vx,ra(:,2),vc,ra(:,2))
     deallocate(ra)
   else
@@ -227,10 +226,10 @@ case(20,21,22)
    .and.present(g3rho).and.present(ex).and.present(ec).and.present(vx) &
    .and.present(vc)) then
     allocate(ra(n,5))
-    ra(:,1)=0.5d0*rho(:)
-    ra(:,2)=0.5d0*grho(:)
-    ra(:,3)=0.5d0*g2rho(:)
-    ra(:,4)=0.25d0*g3rho(:)
+    ra(1:n,1)=0.5d0*rho(1:n)
+    ra(1:n,2)=0.5d0*grho(1:n)
+    ra(1:n,3)=0.5d0*g2rho(1:n)
+    ra(1:n,4)=0.25d0*g3rho(1:n)
     call xc_pbe(n,kappa,mu,beta,ra,ra,grho,ra(:,2),ra(:,2),ra(:,3),ra(:,3), &
      g3rho,ra(:,4),ra(:,4),ex,ec,vx,ra(:,5),vc,ra(:,5))
     deallocate(ra)
@@ -260,11 +259,11 @@ case(50)
   if (present(rhoup).and.present(rhodn).and.present(dtdru) &
    .and.present(dtdrd)) then
     call k_tf_sp(n,rhoup,rhodn,dtdru,dtdrd)
-    if (present(dtdgu2)) dtdgu2(:)=0.d0
-    if (present(dtdgd2)) dtdgd2(:)=0.d0
+    if (present(dtdgu2)) dtdgu2(1:n)=0.d0
+    if (present(dtdgd2)) dtdgd2(1:n)=0.d0
   else if (present(rho).and.present(dtdr)) then
     call k_tf(n,rho,dtdr)
-    if (present(dtdgr2)) dtdgr2(:)=0.d0
+    if (present(dtdgr2)) dtdgr2(1:n)=0.d0
   else
     goto 10
   end if
@@ -359,9 +358,9 @@ case default
 end select
 ! set exchange potential to zero for EXX
 if (xctype(1) <= -2) then
-  if (present(vx)) vx(:)=0.d0
-  if (present(vxup)) vxup(:)=0.d0
-  if (present(vxdn)) vxdn(:)=0.d0
+  if (present(vx)) vx(1:n)=0.d0
+  if (present(vxup)) vxup(1:n)=0.d0
+  if (present(vxdn)) vxdn(1:n)=0.d0
 end if
 return
 10 continue
