@@ -54,6 +54,7 @@ do it=1,maxitoep
 ! calculate the k-dependent residuals
   call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
   do ik=1,nkpt
 ! distribute among MPI processes
@@ -82,6 +83,7 @@ do it=1,maxitoep
   call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is,nrc,nrci,idm) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
   do ias=1,natmtot
     is=idxis(ias)
@@ -95,10 +97,11 @@ do it=1,maxitoep
 !$OMP END PARALLEL DO
   call freethd(nthd)
 ! symmetrise the residuals
-  call symrf(nrcmt,nrcmti,npcmt,ngridg,ngtot,ngvec,igfft,npmtmax,rfmt1,dvxir)
+  call symrf(nrcmt,nrcmti,npcmt,ngridg,ngtot,ngvec,nfgrz,igfft,igrzf,npmtmax, &
+   rfmt1,dvxir)
   if (spinpol) then
-    call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,ngridg,ngtot,ngvec,igfft, &
-     npmtmax,rvfmt,ngtot,dbxir)
+    call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,ngridg,ngtot,ngvec,nfgrz,igfft,&
+     igrzf,npmtmax,rvfmt,ngtot,dbxir)
   end if
 ! magnitude of residuals
   resoep=rfinpc(npmtmax,rfmt1,dvxir,rfmt1,dvxir)
@@ -122,6 +125,7 @@ do it=1,maxitoep
   call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(rfmt2,is,nrc,nrci,npc,idm) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
   do ias=1,natmtot
     is=idxis(ias)
@@ -150,6 +154,7 @@ end do
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is,nrc,nrci,idm) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -181,10 +186,11 @@ do idm=1,ndmag
   bxcir(:,idm)=bxcir(:,idm)+bxir(:,idm)
 end do
 ! symmetrise the exchange potential and field
-call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,igfft,npmtmax,vxcmt,vxcir)
+call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,nfgrz,igfft,igrzf,npmtmax,vxcmt, &
+ vxcir)
 if (spinpol) then
-  call symrvf(.true.,ncmag,nrmt,nrmti,npmt,ngridg,ngtot,ngvec,igfft,npmtmax, &
-   bxcmt,ngtot,bxcir)
+  call symrvf(.true.,ncmag,nrmt,nrmti,npmt,ngridg,ngtot,ngvec,nfgrz,igfft, &
+   igrzf,npmtmax,bxcmt,ngtot,bxcir)
 end if
 deallocate(rfmt1,rfir,vclcv,vclvv)
 if (spinpol) deallocate(rvfmt,rvfir)
