@@ -9,8 +9,7 @@ implicit none
 integer, intent(in) :: ns
 real(8), intent(in) :: r
 integer, intent(in) :: ni
-complex(8), intent(in) :: zi(ni)
-complex(8), intent(in) :: ui(ni)
+complex(8), intent(in) :: zi(ni),ui(ni)
 integer, intent(in) :: no
 complex(8), intent(in) :: zo(no)
 complex(8), intent(out) :: uo(no)
@@ -19,8 +18,8 @@ integer i
 real(8), parameter :: pi=3.1415926535897932385d0
 real(8) t1,t2
 complex(8) z1
-! allocatable arrays
-complex(8), allocatable :: u1(:),u2(:)
+! automatic arrays
+complex(8) u1(ni),u2(no)
 if (ns <= 0) then
   write(*,*)
   write(*,'("Error(pades): ns <= 0 : ",I8)') ns
@@ -31,18 +30,16 @@ if (ns == 1) then
   call pade(ni,zi,ui,no,zo,uo)
   return
 end if
-allocate(u1(ni),u2(no))
-uo(:)=0.d0
+uo(1:no)=0.d0
 do i=1,ns
   t1=dble(i-1)/dble(ns)
   t2=6.d0*pi*t1
   z1=r*t1*cmplx(cos(t2),sin(t2),8)
-  u1(:)=ui(:)+z1
+  u1(1:ni)=ui(1:ni)+z1
   call pade(ni,zi,u1,no,zo,u2)
-  uo(:)=uo(:)+u2(:)-z1
+  uo(1:no)=uo(1:no)+u2(1:no)-z1
 end do
 t1=1.d0/dble(ns)
-uo(:)=t1*uo(:)
-deallocate(u1,u2)
+uo(1:no)=t1*uo(1:no)
 end subroutine
 
