@@ -26,8 +26,7 @@ pure real(8) function polynm(m,np,xa,ya,x)
 implicit none
 ! argmuments
 integer, intent(in) :: m,np
-real(8), intent(in) :: xa(np),ya(np)
-real(8), intent(in) :: x
+real(8), intent(in) :: xa(np),ya(np),x
 ! local variables
 integer i,j,k
 real(8) x0,x1,x2,x3,y0,y1,y2,y3
@@ -120,7 +119,7 @@ if ((np <= 0).or.(m >= np)) then
   return
 end if
 ! find the polynomial coefficients in divided differences form
-c(:)=ya(:)
+c(1:np)=ya(1:np)
 do i=2,np
   do j=np,i,-1
     c(j)=(c(j)-c(j-1))/(xa(j)-xa(j+1-i))
