@@ -48,6 +48,8 @@ do ias=1,natmtot
   vsmt(1:np,ias)=vclmt(1:np,ias)+vxcmt(1:np,ias)
 end do
 vsir(1:ngtot)=vclir(1:ngtot)+vxcir(1:ngtot)
+! multiply interstitial part by characteristic function and store on coarse grid
+call rfirftoc(vsir,vsirc)
 ! generate the effective magnetic fields
 call genbs
 call timesec(ts1)
