@@ -33,8 +33,8 @@ do ifq=2,nfqrz
   end do
 end do
 ! repeat for the interstitial potential
-vsqir(:,1)=vsir(:)
-vsqir(:,2:nfqrz)=0.d0
+vsqir(1:ngtot,1)=vsir(1:ngtot)
+vsqir(1:ngtot,2:nfqrz)=0.d0
 if (.not.spinpol) return
 ! set the Q=0 muffin-tin magnetic field equal to that of the normal ground-state
 do idm=1,ndmag
@@ -54,21 +54,26 @@ do ifq=2,nfqrz
   end do
 end do
 ! repeat for the interstitial magnetic field
-bsqir(:,:,1)=bsir(:,:)
-bsqir(:,:,2:nfqrz)=0.d0
+bsqir(1:ngtot,1:ndmag,1)=bsir(1:ngtot,1:ndmag)
+bsqir(1:ngtot,1:ndmag,2:nfqrz)=0.d0
 ! coupling constant of the external field (g_e/4c)
 cb=gfacte/(4.d0*solsc)
 ! initialise the external magnetic fields
-t1=cb*rndbfcu
-do ifq=1,nfqrz
-  do idm=1,ndmag
-    bfcq(idm,ifq)=t1*cmplx(randomu()-0.5d0,randomu()-0.5d0,8)
-    do ias=1,natmtot
-      bfcmtq(ias,idm,ifq)=t1*cmplx(randomu()-0.5d0,randomu()-0.5d0,8)
+if (abs(rndbfcu) > 0.d0) then
+  t1=cb*rndbfcu
+  do ifq=1,nfqrz
+    do idm=1,ndmag
+      bfcq(idm,ifq)=t1*cmplx(randomu()-0.5d0,randomu()-0.5d0,8)
+      do ias=1,natmtot
+        bfcmtq(ias,idm,ifq)=t1*cmplx(randomu()-0.5d0,randomu()-0.5d0,8)
+      end do
     end do
   end do
-end do
-bfcq(:,1)=dble(bfcq(:,1))
-bfcmtq(:,:,1)=dble(bfcmtq(:,:,1))
+  bfcq(1:ndmag,1)=dble(bfcq(1:ndmag,1))
+  bfcmtq(1:natmtot,1:ndmag,1)=dble(bfcmtq(1:natmtot,1:ndmag,1))
+else
+  bfcq(1:ndmag,1:nfqrz)=0.d0
+  bfcmtq(1:natmtot,1:ndmag,1:nfqrz)=0.d0
+end if
 end subroutine
 
