@@ -41,7 +41,7 @@ call holdthd(natmtot+1,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
 ! muffin-tin exchange-correlation potential, field and energy density
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do ias=1,natmtot
   call potxcmt(tsh,ias,xctype_,rhomt_,magmt_,taumt_,exmt_,ecmt_,vxcmt_,bxcmt_, &
    wxcmt_)
@@ -55,10 +55,11 @@ call potxcir(xctype_,rhoir_,magir_,tauir_,exir_,ecir_,vxcir_,bxcir_,wxcir_)
 if (tsh) then
 !$OMP SECTIONS
 !$OMP SECTION
-  call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,igfft,npmtmax,vxcmt_,vxcir_)
+  call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,nfgrz,igfft,igrzf,npmtmax, &
+   vxcmt_,vxcir_)
 !$OMP SECTION
   if (spinpol) call symrvf(.true.,ncmag,nrmt,nrmti,npmt,ngridg,ngtot,ngvec, &
-   igfft,npmtmax,bxcmt_,ngtot,bxcir_)
+   nfgrz,igfft,igrzf,npmtmax,bxcmt_,ngtot,bxcir_)
 !$OMP END SECTIONS
 end if
 !$OMP END PARALLEL
