@@ -21,6 +21,7 @@ use modvars
 use modgw
 use modbog
 use modw90
+use modtdhfc
 use modmpi
 use modomp
 use modramdisk
@@ -93,7 +94,7 @@ stype=3
 swidth=0.001d0
 autoswidth=.false.
 mstar=10.d0
-epsocc=1.d-8
+epsocc=1.d-10
 epschg=1.d-3
 nempty0=4.d0
 dnempty0=0.d0
@@ -140,6 +141,7 @@ nswplot=1
 wplot(1)=-0.5d0
 wplot(2)=0.5d0
 dosocc=.false.
+tpdos=.true.
 dosmsum=.false.
 dosssum=.false.
 lmirep=.true.
@@ -158,6 +160,11 @@ chgexs=0.d0
 dchgexs=0.d0
 scissor=0.d0
 noptcomp=1
+! list of all optical tensor components
+do k=1,3; do j=1,3; do i=1,3
+  l=(k-1)*9+(j-1)*3+i
+  optcomp(:,l)=[i,j,k]
+end do; end do; end do
 optcomp(:,1)=1
 intraband=.false.
 evaltol=-1.d0
@@ -171,6 +178,9 @@ dbfieldc0(:)=0.d0
 efieldc(:)=0.d0
 dmaxefc=1.d6
 afieldc(:)=0.d0
+dafieldc(:)=0.d0
+afspc(:,:)=0.d0
+dafspc(:,:)=0.d0
 fsmtype=0
 momfix(:)=0.d0
 dmomfix(:)=0.d0
@@ -197,6 +207,7 @@ nosource=.false.
 spinsprl=.false.
 ssdph=.true.
 vqlss(:)=0.d0
+dvqlss(:)=0.d0
 nwrite=0
 dftu=0
 inpdftu=1
@@ -296,6 +307,7 @@ tdjr3d=.false.
 tddos=.false.
 tdlsj=.false.
 tdjtk=.false.
+tdxrmk=.false.
 rndevt0=0.d0
 sxcscf=1.d0
 dsxcscf=0.d0
@@ -319,6 +331,7 @@ actype=10
 npole=3
 nspade=100
 tfav0=.true.
+rmtscf=1.d0
 mrmtav=0
 rmtall=-1.d0
 maxthd=0
@@ -367,12 +380,19 @@ trdatdv=.false.
 atdfc=0.d0
 maxforce=-1.d0
 msmgmt=4
-epsdres=1.d-9
 ntsorth=1000
 deltabf=0.5d0
 jtconst0=.false.
 trmt0=.true.
 ksgwrho=.false.
+npfftg=4
+npfftgc=4
+npfftq=4
+npfftw=4
+tphnat=.false.
+ecutthc=0.01d0
+tbdipu=.false.
+bdipscf=1.d0
 
 !--------------------------!
 !     read from elk.in     !
@@ -838,6 +858,8 @@ case('wplot','dos')
   end if
 case('dosocc')
   read(50,*,err=20) dosocc
+case('tpdos')
+  read(50,*,err=20) tpdos
 case('dosmsum')
   read(50,*,err=20) dosmsum
 case('dosssum')
@@ -896,6 +918,15 @@ case('nprad')
   write(*,'("Info(readinput): variable ''nprad'' is no longer used")')
 case('scissor')
   read(50,*,err=20) scissor
+case('noptcomp')
+  read(50,*,err=20) noptcomp
+  if ((noptcomp < 1).or.(noptcomp > 27)) then
+    write(*,*)
+    write(*,'("Error(readinput): noptcomp should be from 1 to 27 : ",I8)') &
+     noptcomp
+    write(*,*)
+    stop
+  end if
 case('optcomp')
   do i=1,27
     read(50,'(A)',err=20) str
@@ -979,7 +1010,15 @@ case('dmaxefc')
     stop
   end if
 case('afieldc')
-  read(50,*,err=20) afieldc(:)
+  read(50,'(A)',err=20) str
+  read(str,*,err=20) afieldc(:)
+  read(str,*,iostat=ios) afieldc(:),dafieldc(:)
+case('afspc')
+  do i=1,3
+    read(50,'(A)',err=20) str
+    read(str,*,err=20) afspc(i,:)
+    read(str,*,iostat=ios) afspc(i,:),dafspc(i,:)
+  end do
 case('fsmtype','fixspin')
   read(50,*,err=20) fsmtype
 case('momfix')
@@ -1137,7 +1176,9 @@ case('spinsprl')
 case('ssdph')
   read(50,*,err=20) ssdph
 case('vqlss')
-  read(50,*,err=20) vqlss
+  read(50,'(A)',err=20) str
+  read(str,*,err=20) vqlss
+  read(str,*,iostat=ios) vqlss,dvqlss
 case('nwrite')
   read(50,*,err=20) nwrite
 case('DFT+U','dft+u','lda+u')
@@ -1816,6 +1857,8 @@ case('tdlsj')
   read(50,*,err=20) tdlsj
 case('tdjtk')
   read(50,*,err=20) tdjtk
+case('tdxrmk')
+  read(50,*,err=20) tdxrmk
 case('epseph')
   read(50,*,err=20)
   write(*,'("Info(readinput): variable ''epseph'' is no longer used")')
@@ -1894,6 +1937,14 @@ case('nspade')
   end if
 case('tfav0')
   read(50,*,err=20) tfav0
+case('rmtscf')
+  read(50,*,err=20) rmtscf
+  if (rmtscf <= 0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): rmtscf <= 0 : ",G18.10)') rmtscf
+    write(*,*)
+    stop
+  end if
 case('mrmtav')
   read(50,*,err=20) mrmtav
 case('rmtall')
@@ -2095,8 +2146,6 @@ case('maxforce')
   read(50,*,err=20) maxforce
 case('msmgmt','msmg2mt')
   read(50,*,err=20) msmgmt
-case('epsdres')
-  read(50,*,err=20) epsdres
 case('ntsorth')
   read(50,*,err=20) ntsorth
 case('deltabf')
@@ -2113,6 +2162,28 @@ case('trmt0')
   read(50,*,err=20) trmt0
 case('ksgwrho')
   read(50,*,err=20) ksgwrho
+case('npfftg')
+  read(50,*,err=20) npfftg
+case('npfftgc')
+  read(50,*,err=20) npfftgc
+case('npfftq')
+  read(50,*,err=20) npfftq
+case('npfftw')
+  read(50,*,err=20) npfftw
+case('tphnat')
+  read(50,*,err=20) tphnat
+case('ecutthc')
+  read(50,*,err=20) ecutthc
+  if (ecutthc <= 0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): ecutthc <= 0 : ",G18.10)') ecutthc
+    write(*,*)
+    stop
+  end if
+case('tbdipu')
+  read(50,*,err=20) tbdipu
+case('bdipscf')
+  read(50,*,err=20) bdipscf
 case('')
   goto 10
 case default
