@@ -332,9 +332,11 @@ end do
 if (rmtall > 0.d0) then
 ! set all muffin-tin radii to single value if required
   rmt(1:nspecies)=rmtall
-else if (mrmtav > 0) then
+else
+! scale the muffin-tin radii if required
+  if (rmtscf /= 1.d0) rmt(1:nspecies)=rmtscf*rmt(1:nspecies)
 ! apply averaging scheme to the muffin-tin radii
-  call rmtavrg
+  if (mrmtav > 0) call rmtavrg
 end if
 ! make a copy of the muffin-tin radii
 rmt0(1:nspecies)=rmt(1:nspecies)
