@@ -57,7 +57,7 @@ real(8) det
 det=rot(1,1)*(rot(2,2)*rot(3,3)-rot(3,2)*rot(2,3)) &
    +rot(2,1)*(rot(3,2)*rot(1,3)-rot(1,2)*rot(3,3)) &
    +rot(3,1)*(rot(1,2)*rot(2,3)-rot(2,2)*rot(1,3))
-if ((det < 1.d0-eps).or.(det > 1.d0+eps)) then
+if (abs(det-1.d0) > eps) then
   write(*,*)
   write(*,'("Error(roteuler): matrix improper or not unitary")')
   write(*,'(" Determinant : ",G18.10)') det
