@@ -37,37 +37,35 @@ end do
 if (n == 1) return
 l=n/2+1
 k=n
-10 continue
-if (l > 1) then
-  l=l-1
-  m=idx(l)
-else
-  m=idx(k)
-  idx(k)=idx(1)
-  k=k-1
-  if (k == 1) then
-    idx(1)=m
-    return
-  end if
-end if
-i=l
-j=l+l
-20 continue
-if (j <= k) then
-  if (j < k) then
-    if (x(idx(j)) < x(idx(j+1))+eps) j=j+1
-  end if
-  if (x(m) < x(idx(j))+eps) then
-    idx(i)=idx(j)
-    i=j
-    j=j+j
+do
+  if (l > 1) then
+    l=l-1
+    m=idx(l)
   else
-    j=k+1
+    m=idx(k)
+    idx(k)=idx(1)
+    k=k-1
+    if (k == 1) then
+      idx(1)=m
+      return
+    end if
   end if
-  goto 20
-end if
-idx(i)=m
-goto 10
+  i=l
+  j=l+l
+  do while (j <= k)
+    if (j < k) then
+      if (x(idx(j)) < x(idx(j+1))+eps) j=j+1
+    end if
+    if (x(m) < x(idx(j))+eps) then
+      idx(i)=idx(j)
+      i=j
+      j=j+j
+    else
+      j=k+1
+    end if
+  end do
+  idx(i)=m
+end do
 end subroutine
 !EOC
 
