@@ -6,15 +6,18 @@
 !BOP
 ! !ROUTINE: symrfir
 ! !INTERFACE:
-subroutine symrfir(ngdg,ngt,ngv,igf,rfir)
+subroutine symrfir(ngridg_,ngtot_,ngvec_,nfgrz_,igfft_,igrzf_,rfir)
 ! !USES:
 use modmain
 ! !INPUT/OUTPUT PARAMETERS:
-!   ngdg : G-vector grid sizes (in,integer(3))
-!   ngt  : total number of G-vectors (in,integer)
-!   ngv  : number of G-vectors within cut-off (in,integer)
-!   igf  : map from G-vector index to FFT array (in,integer(ngv))
-!   rfir : real intersitial function (inout,real(ngt))
+!   ngridg_ : G-vector grid sizes (in,integer(3))
+!   ngtot_  : total number of G-vectors (in,integer)
+!   ngvec_  : number of G-vectors within cut-off (in,integer)
+!   nfgrz_  : number of FFT elements for real-complex transforms (in,integer)
+!   igfft_  : map from G-vector index to FFT array (in,integer(ngvec_))
+!   igrzf_  : map from real-complex FFT index to G-point index
+!             (in,integer(nfgrz_))
+!   rfir    : real intersitial function (inout,real(ngtot_))
 ! !DESCRIPTION:
 !   Symmetrises a real scalar interstitial function. The function is first
 !   Fourier transformed to $G$-space, and then averaged over each symmetry by
@@ -27,22 +30,23 @@ use modmain
 !BOC
 implicit none
 ! arguments
-integer, intent(in) :: ngdg(3),ngt,ngv,igf(ngv)
-real(8), intent(inout) :: rfir(ngt)
+integer, intent(in) :: ngridg_(3),ngtot_,ngvec_,nfgrz_
+integer, intent(in) :: igfft_(ngvec_),igrzf_(nfgrz_)
+real(8), intent(inout) :: rfir(ngtot_)
 ! local variables
 logical tv0
-integer isym,lspl,ilspl
-integer sym(3,3),ig,ifg,jfg
+integer isym,lspl,sym(3,3)
+integer ig,jg,ifg,jfg
 integer i1,i2,i3,j1,j2,j3
 real(8) v1,v2,v3,t1
 complex(8) z1
 ! allocatable arrays
 complex(8), allocatable :: zfft1(:),zfft2(:)
-allocate(zfft1(ngt),zfft2(ngt))
+allocate(zfft1(ngtot_),zfft2(nfgrz_))
 ! Fourier transform function to G-space
-zfft1(:)=rfir(:)
-call zfftifc(3,ngdg,-1,zfft1)
-zfft2(:)=0.d0
+zfft1(1:ngtot_)=rfir(1:ngtot_)
+call zfftifc(3,ngridg_,-1,zfft1)
+zfft2(1:nfgrz_)=0.d0
 ! loop over crystal symmetries
 do isym=1,nsymcrys
 ! zero translation vector flag
@@ -53,38 +57,39 @@ do isym=1,nsymcrys
     v2=vtcsymc(2,isym)
     v3=vtcsymc(3,isym)
   end if
-! index to lattice symmetry of spatial rotation
+! index to spatial rotation lattice symmetry
   lspl=lsplsymc(isym)
-! inverse rotation required for rotation of G-vectors
-  ilspl=isymlat(lspl)
-  sym(:,:)=symlat(:,:,ilspl)
-  do ig=1,ngv
-    ifg=igf(ig)
+  sym(1:3,1:3)=symlat(1:3,1:3,lspl)
+  do ifg=1,nfgrz_
+    ig=igrzf_(ifg)
+    if (ig > ngvec_) cycle
 ! multiply the transpose of the inverse symmetry matrix with the G-vector
     if (lspl == 1) then
-      jfg=ifg
+      jg=ig
     else
       i1=ivg(1,ig); i2=ivg(2,ig); i3=ivg(3,ig)
       j1=sym(1,1)*i1+sym(2,1)*i2+sym(3,1)*i3
       j2=sym(1,2)*i1+sym(2,2)*i2+sym(3,2)*i3
       j3=sym(1,3)*i1+sym(2,3)*i2+sym(3,3)*i3
-      jfg=igf(ivgig(j1,j2,j3))
+      jg=ivgig(j1,j2,j3)
     end if
+    jfg=igfft_(jg)
+! translation and spatial rotation
     if (tv0) then
 ! zero translation vector
-      zfft2(jfg)=zfft2(jfg)+zfft1(ifg)
+      zfft2(ifg)=zfft2(ifg)+zfft1(jfg)
     else
 ! complex phase factor for translation
-      t1=-(vgc(1,ig)*v1+vgc(2,ig)*v2+vgc(3,ig)*v3)
-      z1=cmplx(cos(t1),sin(t1),8)
-      zfft2(jfg)=zfft2(jfg)+z1*zfft1(ifg)
+      t1=vgc(1,jg)*v1+vgc(2,jg)*v2+vgc(3,jg)*v3
+      z1=cmplx(cos(t1),-sin(t1),8)
+      zfft2(ifg)=zfft2(ifg)+z1*zfft1(jfg)
     end if
   end do
 end do
 ! Fourier transform to real-space and normalise
-call zfftifc(3,ngdg,1,zfft2)
+call rzfftifc(3,ngridg_,1,rfir,zfft2)
 t1=1.d0/dble(nsymcrys)
-rfir(:)=t1*dble(zfft2(:))
+rfir(1:ngtot_)=t1*rfir(1:ngtot_)
 deallocate(zfft1,zfft2)
 end subroutine
 !EOC
