@@ -3,16 +3,15 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine symrfmt(nr,nri,np,ld,rfmt)
+subroutine symrfmt(nrmt_,nrmti_,npmt_,ld,rfmt)
 use modmain
 implicit none
 ! arguments
-integer, intent(in) :: nr(nspecies),nri(nspecies),np(nspecies)
-integer, intent(in) :: ld
+integer, intent(in) :: nrmt_(nspecies),nrmti_(nspecies),npmt_(nspecies),ld
 real(8), intent(inout) :: rfmt(ld,natmtot)
 ! local variables
 integer is,ia,ja,ias,jas
-integer n,isym,lspl
+integer nr,nri,np,isym,lspl
 real(8) t0
 ! automatic arrays
 logical done(natmmax)
@@ -21,18 +20,20 @@ real(8), allocatable :: rfmt1(:,:),rfmt2(:)
 allocate(rfmt1(ld,natmmax),rfmt2(ld))
 t0=1.d0/dble(nsymcrys)
 do is=1,nspecies
-  n=np(is)
+  nr=nrmt_(is)
+  nri=nrmti_(is)
+  np=npmt_(is)
 ! make a copy of the input function
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-    rfmt1(1:n,ia)=rfmt(1:n,ias)
+    rfmt1(1:np,ia)=rfmt(1:np,ias)
   end do
-  done(:)=.false.
+  done(1:natmmax)=.false.
 ! loop over atoms
   do ia=1,natoms(is)
     if (done(ia)) cycle
     ias=idxas(ia,is)
-    rfmt(1:n,ias)=0.d0
+    rfmt(1:np,ias)=0.d0
 ! loop over crystal symmetries
     do isym=1,nsymcrys
 ! index to spatial rotation lattice symmetry
@@ -40,12 +41,12 @@ do is=1,nspecies
 ! equivalent atom index (symmetry rotates atom ja into atom ia)
       ja=ieqatom(ia,is,isym)
 ! apply the rotation to the muffin-tin function
-      call rotrfmt(symlatc(:,:,lspl),nr(is),nri(is),rfmt1(:,ja),rfmt2)
+      call rotrfmt(symlatc(:,:,lspl),nr,nri,rfmt1(:,ja),rfmt2)
 ! accumulate in original function array
-      rfmt(1:n,ias)=rfmt(1:n,ias)+rfmt2(1:n)
+      rfmt(1:np,ias)=rfmt(1:np,ias)+rfmt2(1:np)
     end do
 ! normalise
-    rfmt(1:n,ias)=t0*rfmt(1:n,ias)
+    rfmt(1:np,ias)=t0*rfmt(1:np,ias)
     done(ia)=.true.
 ! rotate into equivalent atoms
     do isym=1,nsymcrys
@@ -55,7 +56,7 @@ do is=1,nspecies
 ! inverse symmetry (which rotates atom ia into atom ja)
       lspl=isymlat(lsplsymc(isym))
 ! rotate symmetrised function into equivalent muffin-tin
-      call rotrfmt(symlatc(:,:,lspl),nr(is),nri(is),rfmt(:,ias),rfmt(:,jas))
+      call rotrfmt(symlatc(:,:,lspl),nr,nri,rfmt(:,ias),rfmt(:,jas))
       done(ja)=.true.
     end do
   end do
