@@ -29,7 +29,7 @@ real(8) v(3),t1
 ! automatic arrays
 real(8) vs(3,natmtot)
 ! make symmetric average
-vs(:,:)=0.d0
+vs(1:3,1:natmtot)=0.d0
 do isym=1,nsymcrys
   lspl=lsplsymc(isym)
   do is=1,nspecies
@@ -38,13 +38,13 @@ do isym=1,nsymcrys
       ja=ieqatom(ia,is,isym)
       jas=idxas(ja,is)
       call r3mv(symlatc(:,:,lspl),vca(:,jas),v)
-      vs(:,ias)=vs(:,ias)+v(:)
+      vs(1:3,ias)=vs(1:3,ias)+v(1:3)
     end do
   end do
 end do
 ! normalise
 t1=1.d0/dble(nsymcrys)
-vca(:,:)=t1*vs(:,:)
+vca(1:3,1:natmtot)=t1*vs(1:3,1:natmtot)
 end subroutine
 !EOC
 
