@@ -65,14 +65,14 @@ do l=0,lmaxo
       if (tevecsv) then
         do jspn=1,nspnfv
           n=ngp(jspn)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
           do j=1,nstfv
             x(j,jspn)=zdotu(n,evecfv(:,j,jspn),1,apwalm(:,io,lm,ias,jspn),1)
           end do
 !$OMP END DO
         end do
 ! loop only over required states
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
         do j=1,nst
 ! index to state in evecsv
           if (tasv) then; k=j; else; k=idx(j); end if
@@ -84,7 +84,7 @@ do l=0,lmaxo
         end do
 !$OMP END DO
       else
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
         do j=1,nst
           if (tasv) then; k=j; else; k=idx(j); end if
           y(p,1,j)=zdotu(ngp(1),evecfv(:,k,1),1,apwalm(:,io,lm,ias,1),1)
@@ -94,9 +94,9 @@ do l=0,lmaxo
     end do
   end do
 end do
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do j=1,nst
-  wfmt(1:np,:,j)=0.d0
+  wfmt(1:np,1:nspinor,j)=0.d0
   do ispn=1,nspinor
     p=0
     do l=0,lmaxo
@@ -105,6 +105,7 @@ do j=1,nst
         do io=1,apword(l,is)
           p=p+1
           z1=y(p,ispn,j)
+          if (abs(dble(z1))+abs(aimag(z1)) < 1.d-10) cycle
           if (ssdph) z1=z1*zq(ispn)
           if (l <= lmaxi) then
             call zfzrf(nri,z1,apwfr(1,1,io,l,ias),lmmaxi,wfmt(lm,ispn,j))
@@ -130,7 +131,7 @@ do ilo=1,nlorb(is)
         n=ngp(jspn)
         x(1:nstfv,jspn)=evecfv(n+i,1:nstfv,jspn)
       end do
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
       do j=1,nst
         if (tasv) then; k=j; else; k=idx(j); end if
         y(p,1,j)=zdotu(nstfv,evecsv(1,k),1,x,1)
@@ -148,7 +149,7 @@ do ilo=1,nlorb(is)
     end if
   end do
 end do
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do j=1,nst
   do ispn=1,nspinor
     p=0
@@ -158,6 +159,7 @@ do j=1,nst
         p=p+1
         i=npi+lm
         z1=y(p,ispn,j)
+        if (abs(dble(z1))+abs(aimag(z1)) < 1.d-10) cycle
         if (ssdph) z1=z1*zq(ispn)
         if (l <= lmaxi) then
           call zfzrf(nri,z1,lofr(1,1,ilo,ias),lmmaxi,wfmt(lm,ispn,j))
@@ -184,7 +186,7 @@ complex(8), intent(in) :: z
 real(8), intent(in) :: rf(lrstp,n)
 integer, intent(in) :: ld
 complex(8), intent(inout) :: zf(ld,n)
-zf(1,:)=zf(1,:)+z*rf(1,:)
+zf(1,1:n)=zf(1,1:n)+z*rf(1,1:n)
 end subroutine
 
 end subroutine
