@@ -36,10 +36,10 @@ integer, intent(in) :: m1,m2,m3
 integer k,k1,k2,l1,l2,l3,n1,n2
 real(8) sgn,sm,t1
 ! external functions
-real(8), external :: factnm,factr
+real(8), external :: factn,factr
 ! check input variables
-if ((j1.lt.0).or.(j2.lt.0).or.(j3.lt.0).or.(abs(m1).gt.j1).or.(abs(m2).gt.j2) &
- .or.(abs(m3).gt.j3)) then
+if ((j1 < 0).or.(j2 < 0).or.(j3 < 0).or.(abs(m1) > j1).or.(abs(m2) > j2) &
+ .or.(abs(m3) > j3)) then
   write(*,*)
   write(*,'("Error(wigner3j): invalid arguments :")')
   write(*,'("j1 = ",I8," j2 = ",I8," j3 = ",I8)') j1,j2,j3
@@ -47,11 +47,11 @@ if ((j1.lt.0).or.(j2.lt.0).or.(j3.lt.0).or.(abs(m1).gt.j1).or.(abs(m2).gt.j2) &
   write(*,*)
   stop
 end if
-if ((j1.eq.0).and.(j2.eq.0).and.(j3.eq.0)) then
+if ((j1 == 0).and.(j2 == 0).and.(j3 == 0)) then
   wigner3j=1.d0
   return
 end if
-if ((j1.gt.50).or.(j2.gt.50).or.(j3.gt.50)) then
+if ((j1 > 50).or.(j2 > 50).or.(j3 > 50)) then
   write(*,*)
   write(*,'("Error(wigner3j): angular momenta out of range : ",3I8)') j1,j2,j3
   write(*,*)
@@ -60,7 +60,7 @@ end if
 l1=j2-j1+j3
 l2=j1-j2+j3
 l3=j1+j2-j3
-if ((m1+m2+m3.ne.0).or.(l1.lt.0).or.(l2.lt.0).or.(l3.lt.0)) then
+if ((m1+m2+m3 /= 0).or.(l1 < 0).or.(l2 < 0).or.(l3 < 0)) then
   wigner3j=0.d0
   return
 end if
@@ -68,7 +68,7 @@ n1=j1-m1
 n2=j2+m2
 k1=max(0,n1-l2,n2-l1)
 k2=min(l3,n1,n2)
-if (mod(k1-j1+j2+m3,2).ne.0) then
+if (mod(k1-j1+j2+m3,2) /= 0) then
   sgn=-1.d0
 else
   sgn=1.d0
@@ -76,11 +76,11 @@ end if
 sm=0.d0
 do k=k1,k2
   t1=sgn*factr(l1,l1-n2+k)*factr(l2,l2-n1+k)*factr(l3,l3-k)
-  sm=sm+t1/(factnm(k,1)*factnm(n1-k,1)*factnm(n2-k,1))
+  sm=sm+t1/(factn(k)*factn(n1-k)*factn(n2-k))
   sgn=-sgn
 end do
 t1=factr(j1+m1,l1)*factr(j2+m2,l2)*factr(j3+m3,l3)
-t1=t1*factr(j3-m3,1+j1+j2+j3)*factnm(j1-m1,1)*factnm(j2-m2,1)
+t1=t1*factr(j3-m3,1+j1+j2+j3)*factn(j1-m1)*factn(j2-m2)
 wigner3j=sm*sqrt(t1)
 end function
 !EOC
