@@ -22,9 +22,9 @@ if (mp_mpi) then
   write(50,*)
   write(50,'("Lattice vector matrix, A, changed by")')
   write(50,*)
-  write(50,'("     A → A + e_k dt,")')
+  write(50,'("     A → A + eₖ dt,")')
   write(50,*)
-  write(50,'("where dt is an infinitesimal scalar and e_k is a strain tensor")')
+  write(50,'("where dt is an infinitesimal scalar and eₖ is a strain tensor")')
   write(50,*)
   write(50,'("Stress is given by the derivative of the total energy dE/dt")')
   do k=1,nstrain
