@@ -26,7 +26,7 @@ complex(4) ylm(lmmaxo),cfft(ngtc)
 !     interstitial contribution     !
 !-----------------------------------!
 ! multiply by coarse characteristic function
-cfft(:)=cfir(:)*cfrc(:)
+cfft(1:ngtc)=cfir(1:ngtc)*cfrc(1:ngtc)
 ! Fourier transform to coarse G-grid
 call cfftifc(3,ngdgc,-1,cfft)
 zfgp(1:ngp)=cfft(igfc(1:ngp))
@@ -49,8 +49,9 @@ do ig=1,ngp
 ! inner part of muffin-tin, note that lmaxi >= 1
       if (lmaxi == 1) then
         do irc=1,nrci
-          zsm=zsm+wrcmt(irc,is)*(jlgpr(j,is,ig)*cfmt(i,ias)*y0+jlgpr(j+1,is,ig)&
-           *(cfmt(i+1,ias)*ylm(2)+cfmt(i+2,ias)*ylm(3)+cfmt(i+3,ias)*ylm(4)))
+          zsm=zsm+wr2cmt(irc,is)*(jlgpr(j,is,ig)*cfmt(i,ias)*y0 &
+           +jlgpr(j+1,is,ig)*(cfmt(i+1,ias)*ylm(2)+cfmt(i+2,ias)*ylm(3) &
+           +cfmt(i+3,ias)*ylm(4)))
           i=i+4
           j=j+2
         end do
@@ -67,7 +68,7 @@ do ig=1,ngp
             i=i+n+1
             j=j+1
           end do
-          zsm=zsm+wrcmt(irc,is)*z1
+          zsm=zsm+wr2cmt(irc,is)*z1
         end do
       end if
 ! outer part of muffin-tin, note that lmaxo >= 3
@@ -90,7 +91,7 @@ do ig=1,ngp
           i=i+n+1
           j=j+1
         end do
-        zsm=zsm+wrcmt(irc,is)*z1
+        zsm=zsm+wr2cmt(irc,is)*z1
       end do
       zfgp(ig)=zfgp(ig)+conjg(sfacgp(ig,ias))*zsm
     end do
